# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class NodeTemplate(pulumi.CustomResource):
    amazonec2_config: pulumi.Output[dict]
    """
    AWS config for the Node Template (list maxitems:1)

      * `access_key` (`str`) - AWS access key. Required on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
      * `ami` (`str`) - AWS machine image (string)
      * `blockDurationMinutes` (`str`) - AWS spot instance duration in minutes (60, 120, 180, 240, 300, or 360). Default `0` (string)
      * `deviceName` (`str`) - AWS root device name. Default `/dev/sda1` (string)
      * `endpoint` (`str`) - Optional endpoint URL (hostname only or fully qualified URI) (string)
      * `iamInstanceProfile` (`str`) - AWS IAM Instance Profile (string)
      * `insecureTransport` (`bool`) - Disable SSL when sending requests (bool)
      * `instanceType` (`str`) - Specifies the Linode Instance type which determines CPU, memory, disk size, etc. Default `g6-standard-4` (string)
      * `keypairName` (`str`) - OpenStack keypair to use to SSH to the instance (string)
      * `monitoring` (`bool`) - Enable monitoring for droplet. Default `false` (bool)
      * `openPorts` (`list`) - Make the specified port number accessible from the Internet. (list)
      * `privateAddressOnly` (`bool`) - Only use a private IP address. Default `false` (bool)
      * `region` (`str`) - OpenStack region name (string)
      * `requestSpotInstance` (`bool`) - Set this flag to request spot instance. Default `false` (bool)
      * `retries` (`str`) - Set retry count for recoverable failures (use -1 to disable). Default `5` (string)
      * `rootSize` (`str`) - AWS root disk size (in GB). Default `16` (string)
      * `secret_key` (`str`) - AWS secret key. Required on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
      * `securityGroupReadonly` (`bool`) - Skip adding default rules to security groups (bool)
      * `securityGroups` (`list`) - AWS VPC security group. (list)
      * `sessionToken` (`str`) - AWS Session Token (string)
      * `spotPrice` (`str`) - AWS spot instance bid price (in dollar). Default `0.50` (string)
      * `sshKeypath` (`str`) - SSH Key for Instance (string)
      * `sshUser` (`str`) - If using a non-B2D image you can specify the ssh user. Default `docker`. From Rancher v2.3.3 (string)
      * `subnetId` (`str`) - AWS VPC subnet id (string)
      * `tags` (`str`) - vSphere tags id e.g. `urn:xxx`. From Rancher v2.3.3 (list)
      * `useEbsOptimizedInstance` (`bool`) - Create an EBS optimized instance. Default `false` (bool)
      * `usePrivateAddress` (`bool`) - Force the usage of private IP address. Default `false` (bool)
      * `userdata` (`str`) - Path to file with cloud-init user-data (string)
      * `volumeType` (`str`) - Amazon EBS volume type. Default `gp2` (string)
      * `vpcId` (`str`) - AWS VPC id. (string)
      * `zone` (`str`) - AWS zone for instance (i.e. a,b,c,d,e) (string)
    """
    annotations: pulumi.Output[dict]
    """
    Annotations for Node Template object (map)
    """
    auth_certificate_authority: pulumi.Output[str]
    """
    Auth certificate authority for the Node Template (string)
    """
    auth_key: pulumi.Output[str]
    """
    Auth key for the Node Template (string)
    """
    azure_config: pulumi.Output[dict]
    """
    Azure config for the Node Template (list maxitems:1)

      * `availabilitySet` (`str`) - Azure Availability Set to place the virtual machine into. Default `docker-machine` (string)
      * `client_id` (`str`) - Azure Service Principal Account ID. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
      * `client_secret` (`str`) - Azure Service Principal Account password. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
      * `customData` (`str`) - Path to file with custom-data (string)
      * `diskSize` (`str`) - vSphere size of disk for docker VM (in MB). Default `20480` (string)
      * `dns` (`str`) - A unique DNS label for the public IP adddress (string)
      * `dockerPort` (`str`) - Docker Port. Default `2376` (string)
      * `environment` (`str`) - Azure environment (e.g. AzurePublicCloud, AzureChinaCloud). Default `AzurePublicCloud` (string)
        `fault_domain_count` - (Optional) Fault domain count to use for availability set. Default `3` (string)
      * `faultDomainCount` (`str`)
      * `image` (`str`) - Specifies the Linode Instance image which determines the OS distribution and base files. Default `linode/ubuntu18.04` (string)
      * `location` (`str`) - Azure region to create the virtual machine. Default `westus` (string)
      * `managedDisks` (`bool`) - Configures VM and availability set for managed disks. Just for Rancher v2.3.x and above. Default `false` (bool)
      * `noPublicIp` (`bool`) - Do not create a public IP address for the machine. Default `false` (bool)
      * `openPorts` (`list`) - Make the specified port number accessible from the Internet. (list)
      * `privateIpAddress` (`str`) - Specify a static private IP address for the machine. (string)
      * `resourceGroup` (`str`) - Azure Resource Group name (will be created if missing). Default `docker-machine` (string)
      * `size` (`str`) - Digital Ocean size. Default `s-1vcpu-1gb` (string)
      * `sshUser` (`str`) - If using a non-B2D image you can specify the ssh user. Default `docker`. From Rancher v2.3.3 (string)
      * `staticPublicIp` (`bool`) - Assign a static public IP address to the machine. Default `false` (bool)
      * `storageType` (`str`) - Type of Storage Account to host the OS Disk for the machine. Default `Standard_LRS` (string)
      * `subnet` (`str`) - Azure Subnet Name to be used within the Virtual Network. Default `docker-machine` (string)
      * `subnetPrefix` (`str`) - Private CIDR block to be used for the new subnet, should comply RFC 1918. Default `192.168.0.0/16` (string)
      * `subscriptionId` (`str`) - Azure Subscription ID. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
      * `updateDomainCount` (`str`) - Update domain count to use for availability set. Default `5` (string)
      * `usePrivateIp` (`bool`) - Use private IP address of the machine to connect. Default `false` (bool)
      * `vnet` (`str`) - Azure Virtual Network name to connect the virtual machine (in [resourcegroup:]name format). Default `docker-machine-vnet` (string)
    """
    cloud_credential_id: pulumi.Output[str]
    """
    Cloud credential ID for the Node Template. Required from Rancher v2.2.x (string)
    """
    description: pulumi.Output[str]
    """
    Description for the Node Template (string)
    """
    digitalocean_config: pulumi.Output[dict]
    """
    Digitalocean config for the Node Template (list maxitems:1)

      * `accessToken` (`str`) - Digital Ocean access token. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
      * `backups` (`bool`) - Enable backups for droplet. Default `false` (bool)
      * `image` (`str`) - Specifies the Linode Instance image which determines the OS distribution and base files. Default `linode/ubuntu18.04` (string)
      * `ipv6` (`bool`) - Enable ipv6 for droplet. Default `false` (bool)
      * `monitoring` (`bool`) - Enable monitoring for droplet. Default `false` (bool)
      * `privateNetworking` (`bool`) - Enable private networking for droplet. Default `false` (bool)
      * `region` (`str`) - OpenStack region name (string)
      * `size` (`str`) - Digital Ocean size. Default `s-1vcpu-1gb` (string)
      * `sshKeyFingerprint` (`str`) - SSH key fingerprint (string)
      * `sshKeyPath` (`str`) - SSH private key path (string)
      * `sshPort` (`str`) - If using a non-B2D image you can specify the ssh port. Default `22`. From Rancher v2.3.3 (string)
      * `sshUser` (`str`) - If using a non-B2D image you can specify the ssh user. Default `docker`. From Rancher v2.3.3 (string)
      * `tags` (`str`) - vSphere tags id e.g. `urn:xxx`. From Rancher v2.3.3 (list)
      * `userdata` (`str`) - Path to file with cloud-init user-data (string)
    """
    driver: pulumi.Output[str]
    """
    (Computed) The driver of the node template (string)
    """
    driver_id: pulumi.Output[str]
    """
    The node driver id used by the node template. It's required if the node driver isn't built in Rancher (string)
    """
    engine_env: pulumi.Output[dict]
    """
    Engine environment for the node template (string)
    """
    engine_insecure_registries: pulumi.Output[list]
    """
    Insecure registry for the node template (list)
    """
    engine_install_url: pulumi.Output[str]
    """
    Docker engine install URL for the node template. Default `https://releases.rancher.com/install-docker/18.09.sh`. Available install docker versions at `https://github.com/rancher/install-docker` (string)
    """
    engine_label: pulumi.Output[dict]
    """
    Engine label for the node template (string)
    """
    engine_opt: pulumi.Output[dict]
    """
    Engine options for the node template (map)
    """
    engine_registry_mirrors: pulumi.Output[list]
    """
    Engine registry mirror for the node template (list)
    """
    engine_storage_driver: pulumi.Output[str]
    """
    Engine storage driver for the node template (string)
    """
    labels: pulumi.Output[dict]
    """
    Labels for Node Template object (map)
    """
    linode_config: pulumi.Output[dict]
    """
    Linode config for the Node Template (list maxitems:1)

      * `authorizedUsers` (`str`) - Linode user accounts (seperated by commas) whose Linode SSH keys will be permitted root access to the created node. (string)
      * `createPrivateIp` (`bool`) - Create private IP for the instance. Default `false` (bool)
      * `dockerPort` (`str`) - Docker Port. Default `2376` (string)
      * `image` (`str`) - Specifies the Linode Instance image which determines the OS distribution and base files. Default `linode/ubuntu18.04` (string)
      * `instanceType` (`str`) - Specifies the Linode Instance type which determines CPU, memory, disk size, etc. Default `g6-standard-4` (string)
      * `label` (`str`) - Linode Instance Label. (string)
      * `region` (`str`) - OpenStack region name (string)
      * `rootPass` (`str`) - Root Password (string)
      * `sshPort` (`str`) - If using a non-B2D image you can specify the ssh port. Default `22`. From Rancher v2.3.3 (string)
      * `sshUser` (`str`) - If using a non-B2D image you can specify the ssh user. Default `docker`. From Rancher v2.3.3 (string)
      * `stackscript` (`str`) - Specifies the Linode StackScript to use to create the instance. (string)
      * `stackscriptData` (`str`) - A JSON string specifying data for the selected StackScript. (string)
      * `swapSize` (`str`) - Linode Instance Swap Size (MB). Default `512` (string)
      * `tags` (`str`) - vSphere tags id e.g. `urn:xxx`. From Rancher v2.3.3 (list)
      * `token` (`str`) - Linode API token. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
      * `uaPrefix` (`str`) - Prefix the User-Agent in Linode API calls with some 'product/version' (string)
    """
    name: pulumi.Output[str]
    """
    The name of the Node Template (string)
    """
    opennebula_config: pulumi.Output[dict]
    """
    Opennebula config for the Node Template (list maxitems:1)

      * `b2dSize` (`str`) - Size of the Volatile disk in MB - only for b2d (string)
      * `cpu` (`str`) - CPU value for the VM (string)
      * `devPrefix` (`str`) - Dev prefix to use for the images. E.g.: 'vd', 'sd', 'hd' (string)
      * `disableVnc` (`bool`) - VNC is enabled by default. Disable it with this flag (bool)
      * `diskResize` (`str`) - Size of the disk for the VM in MB (string)
      * `imageId` (`str`) - OpenStack image id to use for the instance. Conflicts with `image_name` (string)
      * `imageName` (`str`) - OpenStack image name to use for the instance. Conflicts with `image_id` (string)
      * `imageOwner` (`str`) - Owner of the image to use as the VM OS (string)
      * `memory` (`str`) - Size of the memory for the VM in MB (string)
      * `networkId` (`str`) - Opennebula network ID to connect the machine to. Conflicts with `network_name` (string)
      * `networkName` (`str`) - Opennebula network to connect the machine to. Conflicts with `network_id` (string)
      * `networkOwner` (`str`) - Opennebula user ID of the Network to connect the machine to (string)
      * `password` (`str`) - vSphere password. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
      * `sshUser` (`str`) - If using a non-B2D image you can specify the ssh user. Default `docker`. From Rancher v2.3.3 (string)
      * `templateId` (`str`) - Opennebula template ID to use. Conflicts with `template_name` (string)
      * `template_name` (`str`) - Name of the Opennbula template to use. Conflicts with `template_id` (string)
      * `user` (`str`) - Set the user for the XML-RPC API authentication (string)
      * `vcpu` (`str`) - VCPUs for the VM (string)
      * `xmlRpcUrl` (`str`) - Set the url for the Opennebula XML-RPC API (string)
    """
    openstack_config: pulumi.Output[dict]
    """
    Openstack config for the Node Template (list maxitems:1)

      * `activeTimeout` (`str`) - OpenStack active timeout Default `200` (string)
      * `authUrl` (`str`) - OpenStack authentication URL (string)
      * `availabilityZone` (`str`) - OpenStack availability zone (string)
      * `cacert` (`str`) - CA certificate bundle to verify against (string)
      * `configDrive` (`bool`) - Enables the OpenStack config drive for the instance. Default `false` (bool)
      * `domainId` (`str`) - OpenStack domain ID. Identity v3 only. Conflicts with `domain_name` (string)
      * `domainName` (`str`) - OpenStack domain name. Identity v3 only. Conflicts with `domain_id` (string)
      * `endpointType` (`str`) - OpenStack endpoint type. adminURL, internalURL or publicURL (string)
      * `flavorId` (`str`) - OpenStack flavor id to use for the instance. Conflicts with `flavor_name` (string)
      * `flavorName` (`str`) - OpenStack flavor name to use for the instance. Conflicts with `flavor_id` (string)
      * `floatingIpPool` (`str`) - OpenStack floating IP pool to get an IP from to assign to the instance (string)
      * `imageId` (`str`) - OpenStack image id to use for the instance. Conflicts with `image_name` (string)
      * `imageName` (`str`) - OpenStack image name to use for the instance. Conflicts with `image_id` (string)
      * `insecure` (`bool`) - Disable TLS credential checking. Default `false` (bool)
      * `ipVersion` (`str`) - OpenStack version of IP address assigned for the machine Default `4` (string)
      * `keypairName` (`str`) - OpenStack keypair to use to SSH to the instance (string)
      * `netId` (`str`) - OpenStack network id the machine will be connected on. Conflicts with `net_name` (string)
      * `netName` (`str`) - OpenStack network name the machine will be connected on. Conflicts with `net_id` (string)
      * `novaNetwork` (`bool`) - Use the nova networking services instead of neutron (string)
      * `password` (`str`) - vSphere password. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
      * `privateKeyFile` (`str`) - Private key content to use for SSH (string)
      * `region` (`str`) - OpenStack region name (string)
      * `secGroups` (`str`) - OpenStack comma separated security groups for the machine (string)
      * `sshPort` (`str`) - If using a non-B2D image you can specify the ssh port. Default `22`. From Rancher v2.3.3 (string)
      * `sshUser` (`str`) - If using a non-B2D image you can specify the ssh user. Default `docker`. From Rancher v2.3.3 (string)
      * `tenant_id` (`str`) - OpenStack tenant id. Conflicts with `tenant_name` (string)
      * `tenantName` (`str`) - OpenStack tenant name. Conflicts with `tenant_id` (string)
      * `userDataFile` (`str`) - File containing an openstack userdata script (string)
      * `username` (`str`) - vSphere username. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
    """
    use_internal_ip_address: pulumi.Output[bool]
    """
    Engine storage driver for the node template (bool)
    """
    vsphere_config: pulumi.Output[dict]
    """
    vSphere config for the Node Template (list maxitems:1)

      * `boot2dockerUrl` (`str`) - vSphere URL for boot2docker iso image. Default `https://releases.rancher.com/os/latest/rancheros-vmware.iso` (string)
      * `cfgparams` (`list`) - vSphere vm configuration parameters (used for guestinfo) (list)
      * `cloneFrom` (`str`) - If you choose creation type clone a name of what you want to clone is required. From Rancher v2.3.3 (string)
      * `cloudConfig` (`str`) - Filepath to a cloud-config yaml file to put into the ISO user-data. From Rancher v2.3.3 (string)
      * `cloudinit` (`str`) - vSphere cloud-init file or url to set in the guestinfo (string)
      * `contentLibrary` (`str`) - If you choose to clone from a content library template specify the name of the library. From Rancher v2.3.3 (string)
      * `cpuCount` (`str`) - vSphere CPU number for docker VM. Default `2` (string)
      * `creationType` (`str`) - Creation type when creating a new virtual machine. Supported values: vm, template, library, legacy. Default `legacy`. From Rancher v2.3.3 (string)
      * `customAttributes` (`list`) - vSphere custom attributes, format key/value e.g. `200=my custom value`. From Rancher v2.3.3 (List)
      * `datacenter` (`str`) - vSphere datacenter for docker VM (string)
      * `datastore` (`str`) - vSphere datastore for docker VM (string)
      * `datastoreCluster` (`str`) - vSphere datastore cluster for virtual machine. From Rancher v2.3.3 (string)
      * `diskSize` (`str`) - vSphere size of disk for docker VM (in MB). Default `20480` (string)
      * `folder` (`str`) - vSphere folder for the docker VM. This folder must already exist in the datacenter (string)
      * `hostsystem` (`str`) - vSphere compute resource where the docker VM will be instantiated. This can be omitted if using a cluster with DRS (string)
      * `memorySize` (`str`) - vSphere size of memory for docker VM (in MB). Default `2048` (string)
      * `networks` (`list`) - vSphere network where the docker VM will be attached (list)
      * `password` (`str`) - vSphere password. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
      * `pool` (`str`) - vSphere resource pool for docker VM (string)
      * `sshPassword` (`str`) - If using a non-B2D image you can specify the ssh password. Default `tcuser`. From Rancher v2.3.3 (string)
      * `sshPort` (`str`) - If using a non-B2D image you can specify the ssh port. Default `22`. From Rancher v2.3.3 (string)
      * `sshUser` (`str`) - If using a non-B2D image you can specify the ssh user. Default `docker`. From Rancher v2.3.3 (string)
      * `sshUserGroup` (`str`) - If using a non-B2D image the uploaded keys will need chown'ed. Default `staff`. From Rancher v2.3.3 (string)
      * `tags` (`list`) - vSphere tags id e.g. `urn:xxx`. From Rancher v2.3.3 (list)
      * `username` (`str`) - vSphere username. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
      * `vappIpAllocationPolicy` (`str`) - vSphere vApp IP allocation policy. Supported values are: `dhcp`, `fixed`, `transient` and `fixedAllocated` (string)
      * `vappIpProtocol` (`str`) - vSphere vApp IP protocol for this deployment. Supported values are: `IPv4` and `IPv6` (string)
      * `vappProperties` (`list`) - vSphere vApp properties (list)
      * `vappTransport` (`str`) - vSphere OVF environment transports to use for properties. Supported values are: `iso` and `com.vmware.guestInfo` (string)
      * `vcenter` (`str`) - vSphere IP/hostname for vCenter. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
      * `vcenterPort` (`str`) - vSphere Port for vCenter. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x. Default `443` (string)
    """
    def __init__(__self__, resource_name, opts=None, amazonec2_config=None, annotations=None, auth_certificate_authority=None, auth_key=None, azure_config=None, cloud_credential_id=None, description=None, digitalocean_config=None, driver_id=None, engine_env=None, engine_insecure_registries=None, engine_install_url=None, engine_label=None, engine_opt=None, engine_registry_mirrors=None, engine_storage_driver=None, labels=None, linode_config=None, name=None, opennebula_config=None, openstack_config=None, use_internal_ip_address=None, vsphere_config=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Rancher v2 Node Template resource. This can be used to create Node Template for Rancher v2 and retrieve their information.

        amazonec2, azure, digitalocean, linode, opennebula, openstack, and vsphere drivers are supported for node templates.

        **Note** If you are upgrading to Rancher v2.3.3, please take a look to final section



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] amazonec2_config: AWS config for the Node Template (list maxitems:1)
        :param pulumi.Input[dict] annotations: Annotations for Node Template object (map)
        :param pulumi.Input[str] auth_certificate_authority: Auth certificate authority for the Node Template (string)
        :param pulumi.Input[str] auth_key: Auth key for the Node Template (string)
        :param pulumi.Input[dict] azure_config: Azure config for the Node Template (list maxitems:1)
        :param pulumi.Input[str] cloud_credential_id: Cloud credential ID for the Node Template. Required from Rancher v2.2.x (string)
        :param pulumi.Input[str] description: Description for the Node Template (string)
        :param pulumi.Input[dict] digitalocean_config: Digitalocean config for the Node Template (list maxitems:1)
        :param pulumi.Input[str] driver_id: The node driver id used by the node template. It's required if the node driver isn't built in Rancher (string)
        :param pulumi.Input[dict] engine_env: Engine environment for the node template (string)
        :param pulumi.Input[list] engine_insecure_registries: Insecure registry for the node template (list)
        :param pulumi.Input[str] engine_install_url: Docker engine install URL for the node template. Default `https://releases.rancher.com/install-docker/18.09.sh`. Available install docker versions at `https://github.com/rancher/install-docker` (string)
        :param pulumi.Input[dict] engine_label: Engine label for the node template (string)
        :param pulumi.Input[dict] engine_opt: Engine options for the node template (map)
        :param pulumi.Input[list] engine_registry_mirrors: Engine registry mirror for the node template (list)
        :param pulumi.Input[str] engine_storage_driver: Engine storage driver for the node template (string)
        :param pulumi.Input[dict] labels: Labels for Node Template object (map)
        :param pulumi.Input[dict] linode_config: Linode config for the Node Template (list maxitems:1)
        :param pulumi.Input[str] name: The name of the Node Template (string)
        :param pulumi.Input[dict] opennebula_config: Opennebula config for the Node Template (list maxitems:1)
        :param pulumi.Input[dict] openstack_config: Openstack config for the Node Template (list maxitems:1)
        :param pulumi.Input[bool] use_internal_ip_address: Engine storage driver for the node template (bool)
        :param pulumi.Input[dict] vsphere_config: vSphere config for the Node Template (list maxitems:1)

        The **amazonec2_config** object supports the following:

          * `access_key` (`pulumi.Input[str]`) - AWS access key. Required on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `ami` (`pulumi.Input[str]`) - AWS machine image (string)
          * `blockDurationMinutes` (`pulumi.Input[str]`) - AWS spot instance duration in minutes (60, 120, 180, 240, 300, or 360). Default `0` (string)
          * `deviceName` (`pulumi.Input[str]`) - AWS root device name. Default `/dev/sda1` (string)
          * `endpoint` (`pulumi.Input[str]`) - Optional endpoint URL (hostname only or fully qualified URI) (string)
          * `iamInstanceProfile` (`pulumi.Input[str]`) - AWS IAM Instance Profile (string)
          * `insecureTransport` (`pulumi.Input[bool]`) - Disable SSL when sending requests (bool)
          * `instanceType` (`pulumi.Input[str]`) - Specifies the Linode Instance type which determines CPU, memory, disk size, etc. Default `g6-standard-4` (string)
          * `keypairName` (`pulumi.Input[str]`) - OpenStack keypair to use to SSH to the instance (string)
          * `monitoring` (`pulumi.Input[bool]`) - Enable monitoring for droplet. Default `false` (bool)
          * `openPorts` (`pulumi.Input[list]`) - Make the specified port number accessible from the Internet. (list)
          * `privateAddressOnly` (`pulumi.Input[bool]`) - Only use a private IP address. Default `false` (bool)
          * `region` (`pulumi.Input[str]`) - OpenStack region name (string)
          * `requestSpotInstance` (`pulumi.Input[bool]`) - Set this flag to request spot instance. Default `false` (bool)
          * `retries` (`pulumi.Input[str]`) - Set retry count for recoverable failures (use -1 to disable). Default `5` (string)
          * `rootSize` (`pulumi.Input[str]`) - AWS root disk size (in GB). Default `16` (string)
          * `secret_key` (`pulumi.Input[str]`) - AWS secret key. Required on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `securityGroupReadonly` (`pulumi.Input[bool]`) - Skip adding default rules to security groups (bool)
          * `securityGroups` (`pulumi.Input[list]`) - AWS VPC security group. (list)
          * `sessionToken` (`pulumi.Input[str]`) - AWS Session Token (string)
          * `spotPrice` (`pulumi.Input[str]`) - AWS spot instance bid price (in dollar). Default `0.50` (string)
          * `sshKeypath` (`pulumi.Input[str]`) - SSH Key for Instance (string)
          * `sshUser` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh user. Default `docker`. From Rancher v2.3.3 (string)
          * `subnetId` (`pulumi.Input[str]`) - AWS VPC subnet id (string)
          * `tags` (`pulumi.Input[str]`) - vSphere tags id e.g. `urn:xxx`. From Rancher v2.3.3 (list)
          * `useEbsOptimizedInstance` (`pulumi.Input[bool]`) - Create an EBS optimized instance. Default `false` (bool)
          * `usePrivateAddress` (`pulumi.Input[bool]`) - Force the usage of private IP address. Default `false` (bool)
          * `userdata` (`pulumi.Input[str]`) - Path to file with cloud-init user-data (string)
          * `volumeType` (`pulumi.Input[str]`) - Amazon EBS volume type. Default `gp2` (string)
          * `vpcId` (`pulumi.Input[str]`) - AWS VPC id. (string)
          * `zone` (`pulumi.Input[str]`) - AWS zone for instance (i.e. a,b,c,d,e) (string)

        The **azure_config** object supports the following:

          * `availabilitySet` (`pulumi.Input[str]`) - Azure Availability Set to place the virtual machine into. Default `docker-machine` (string)
          * `client_id` (`pulumi.Input[str]`) - Azure Service Principal Account ID. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `client_secret` (`pulumi.Input[str]`) - Azure Service Principal Account password. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `customData` (`pulumi.Input[str]`) - Path to file with custom-data (string)
          * `diskSize` (`pulumi.Input[str]`) - vSphere size of disk for docker VM (in MB). Default `20480` (string)
          * `dns` (`pulumi.Input[str]`) - A unique DNS label for the public IP adddress (string)
          * `dockerPort` (`pulumi.Input[str]`) - Docker Port. Default `2376` (string)
          * `environment` (`pulumi.Input[str]`) - Azure environment (e.g. AzurePublicCloud, AzureChinaCloud). Default `AzurePublicCloud` (string)
            `fault_domain_count` - (Optional) Fault domain count to use for availability set. Default `3` (string)
          * `faultDomainCount` (`pulumi.Input[str]`)
          * `image` (`pulumi.Input[str]`) - Specifies the Linode Instance image which determines the OS distribution and base files. Default `linode/ubuntu18.04` (string)
          * `location` (`pulumi.Input[str]`) - Azure region to create the virtual machine. Default `westus` (string)
          * `managedDisks` (`pulumi.Input[bool]`) - Configures VM and availability set for managed disks. Just for Rancher v2.3.x and above. Default `false` (bool)
          * `noPublicIp` (`pulumi.Input[bool]`) - Do not create a public IP address for the machine. Default `false` (bool)
          * `openPorts` (`pulumi.Input[list]`) - Make the specified port number accessible from the Internet. (list)
          * `privateIpAddress` (`pulumi.Input[str]`) - Specify a static private IP address for the machine. (string)
          * `resourceGroup` (`pulumi.Input[str]`) - Azure Resource Group name (will be created if missing). Default `docker-machine` (string)
          * `size` (`pulumi.Input[str]`) - Digital Ocean size. Default `s-1vcpu-1gb` (string)
          * `sshUser` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh user. Default `docker`. From Rancher v2.3.3 (string)
          * `staticPublicIp` (`pulumi.Input[bool]`) - Assign a static public IP address to the machine. Default `false` (bool)
          * `storageType` (`pulumi.Input[str]`) - Type of Storage Account to host the OS Disk for the machine. Default `Standard_LRS` (string)
          * `subnet` (`pulumi.Input[str]`) - Azure Subnet Name to be used within the Virtual Network. Default `docker-machine` (string)
          * `subnetPrefix` (`pulumi.Input[str]`) - Private CIDR block to be used for the new subnet, should comply RFC 1918. Default `192.168.0.0/16` (string)
          * `subscriptionId` (`pulumi.Input[str]`) - Azure Subscription ID. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `updateDomainCount` (`pulumi.Input[str]`) - Update domain count to use for availability set. Default `5` (string)
          * `usePrivateIp` (`pulumi.Input[bool]`) - Use private IP address of the machine to connect. Default `false` (bool)
          * `vnet` (`pulumi.Input[str]`) - Azure Virtual Network name to connect the virtual machine (in [resourcegroup:]name format). Default `docker-machine-vnet` (string)

        The **digitalocean_config** object supports the following:

          * `accessToken` (`pulumi.Input[str]`) - Digital Ocean access token. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `backups` (`pulumi.Input[bool]`) - Enable backups for droplet. Default `false` (bool)
          * `image` (`pulumi.Input[str]`) - Specifies the Linode Instance image which determines the OS distribution and base files. Default `linode/ubuntu18.04` (string)
          * `ipv6` (`pulumi.Input[bool]`) - Enable ipv6 for droplet. Default `false` (bool)
          * `monitoring` (`pulumi.Input[bool]`) - Enable monitoring for droplet. Default `false` (bool)
          * `privateNetworking` (`pulumi.Input[bool]`) - Enable private networking for droplet. Default `false` (bool)
          * `region` (`pulumi.Input[str]`) - OpenStack region name (string)
          * `size` (`pulumi.Input[str]`) - Digital Ocean size. Default `s-1vcpu-1gb` (string)
          * `sshKeyFingerprint` (`pulumi.Input[str]`) - SSH key fingerprint (string)
          * `sshKeyPath` (`pulumi.Input[str]`) - SSH private key path (string)
          * `sshPort` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh port. Default `22`. From Rancher v2.3.3 (string)
          * `sshUser` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh user. Default `docker`. From Rancher v2.3.3 (string)
          * `tags` (`pulumi.Input[str]`) - vSphere tags id e.g. `urn:xxx`. From Rancher v2.3.3 (list)
          * `userdata` (`pulumi.Input[str]`) - Path to file with cloud-init user-data (string)

        The **linode_config** object supports the following:

          * `authorizedUsers` (`pulumi.Input[str]`) - Linode user accounts (seperated by commas) whose Linode SSH keys will be permitted root access to the created node. (string)
          * `createPrivateIp` (`pulumi.Input[bool]`) - Create private IP for the instance. Default `false` (bool)
          * `dockerPort` (`pulumi.Input[str]`) - Docker Port. Default `2376` (string)
          * `image` (`pulumi.Input[str]`) - Specifies the Linode Instance image which determines the OS distribution and base files. Default `linode/ubuntu18.04` (string)
          * `instanceType` (`pulumi.Input[str]`) - Specifies the Linode Instance type which determines CPU, memory, disk size, etc. Default `g6-standard-4` (string)
          * `label` (`pulumi.Input[str]`) - Linode Instance Label. (string)
          * `region` (`pulumi.Input[str]`) - OpenStack region name (string)
          * `rootPass` (`pulumi.Input[str]`) - Root Password (string)
          * `sshPort` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh port. Default `22`. From Rancher v2.3.3 (string)
          * `sshUser` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh user. Default `docker`. From Rancher v2.3.3 (string)
          * `stackscript` (`pulumi.Input[str]`) - Specifies the Linode StackScript to use to create the instance. (string)
          * `stackscriptData` (`pulumi.Input[str]`) - A JSON string specifying data for the selected StackScript. (string)
          * `swapSize` (`pulumi.Input[str]`) - Linode Instance Swap Size (MB). Default `512` (string)
          * `tags` (`pulumi.Input[str]`) - vSphere tags id e.g. `urn:xxx`. From Rancher v2.3.3 (list)
          * `token` (`pulumi.Input[str]`) - Linode API token. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `uaPrefix` (`pulumi.Input[str]`) - Prefix the User-Agent in Linode API calls with some 'product/version' (string)

        The **opennebula_config** object supports the following:

          * `b2dSize` (`pulumi.Input[str]`) - Size of the Volatile disk in MB - only for b2d (string)
          * `cpu` (`pulumi.Input[str]`) - CPU value for the VM (string)
          * `devPrefix` (`pulumi.Input[str]`) - Dev prefix to use for the images. E.g.: 'vd', 'sd', 'hd' (string)
          * `disableVnc` (`pulumi.Input[bool]`) - VNC is enabled by default. Disable it with this flag (bool)
          * `diskResize` (`pulumi.Input[str]`) - Size of the disk for the VM in MB (string)
          * `imageId` (`pulumi.Input[str]`) - OpenStack image id to use for the instance. Conflicts with `image_name` (string)
          * `imageName` (`pulumi.Input[str]`) - OpenStack image name to use for the instance. Conflicts with `image_id` (string)
          * `imageOwner` (`pulumi.Input[str]`) - Owner of the image to use as the VM OS (string)
          * `memory` (`pulumi.Input[str]`) - Size of the memory for the VM in MB (string)
          * `networkId` (`pulumi.Input[str]`) - Opennebula network ID to connect the machine to. Conflicts with `network_name` (string)
          * `networkName` (`pulumi.Input[str]`) - Opennebula network to connect the machine to. Conflicts with `network_id` (string)
          * `networkOwner` (`pulumi.Input[str]`) - Opennebula user ID of the Network to connect the machine to (string)
          * `password` (`pulumi.Input[str]`) - vSphere password. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `sshUser` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh user. Default `docker`. From Rancher v2.3.3 (string)
          * `templateId` (`pulumi.Input[str]`) - Opennebula template ID to use. Conflicts with `template_name` (string)
          * `template_name` (`pulumi.Input[str]`) - Name of the Opennbula template to use. Conflicts with `template_id` (string)
          * `user` (`pulumi.Input[str]`) - Set the user for the XML-RPC API authentication (string)
          * `vcpu` (`pulumi.Input[str]`) - VCPUs for the VM (string)
          * `xmlRpcUrl` (`pulumi.Input[str]`) - Set the url for the Opennebula XML-RPC API (string)

        The **openstack_config** object supports the following:

          * `activeTimeout` (`pulumi.Input[str]`) - OpenStack active timeout Default `200` (string)
          * `authUrl` (`pulumi.Input[str]`) - OpenStack authentication URL (string)
          * `availabilityZone` (`pulumi.Input[str]`) - OpenStack availability zone (string)
          * `cacert` (`pulumi.Input[str]`) - CA certificate bundle to verify against (string)
          * `configDrive` (`pulumi.Input[bool]`) - Enables the OpenStack config drive for the instance. Default `false` (bool)
          * `domainId` (`pulumi.Input[str]`) - OpenStack domain ID. Identity v3 only. Conflicts with `domain_name` (string)
          * `domainName` (`pulumi.Input[str]`) - OpenStack domain name. Identity v3 only. Conflicts with `domain_id` (string)
          * `endpointType` (`pulumi.Input[str]`) - OpenStack endpoint type. adminURL, internalURL or publicURL (string)
          * `flavorId` (`pulumi.Input[str]`) - OpenStack flavor id to use for the instance. Conflicts with `flavor_name` (string)
          * `flavorName` (`pulumi.Input[str]`) - OpenStack flavor name to use for the instance. Conflicts with `flavor_id` (string)
          * `floatingIpPool` (`pulumi.Input[str]`) - OpenStack floating IP pool to get an IP from to assign to the instance (string)
          * `imageId` (`pulumi.Input[str]`) - OpenStack image id to use for the instance. Conflicts with `image_name` (string)
          * `imageName` (`pulumi.Input[str]`) - OpenStack image name to use for the instance. Conflicts with `image_id` (string)
          * `insecure` (`pulumi.Input[bool]`) - Disable TLS credential checking. Default `false` (bool)
          * `ipVersion` (`pulumi.Input[str]`) - OpenStack version of IP address assigned for the machine Default `4` (string)
          * `keypairName` (`pulumi.Input[str]`) - OpenStack keypair to use to SSH to the instance (string)
          * `netId` (`pulumi.Input[str]`) - OpenStack network id the machine will be connected on. Conflicts with `net_name` (string)
          * `netName` (`pulumi.Input[str]`) - OpenStack network name the machine will be connected on. Conflicts with `net_id` (string)
          * `novaNetwork` (`pulumi.Input[bool]`) - Use the nova networking services instead of neutron (string)
          * `password` (`pulumi.Input[str]`) - vSphere password. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `privateKeyFile` (`pulumi.Input[str]`) - Private key content to use for SSH (string)
          * `region` (`pulumi.Input[str]`) - OpenStack region name (string)
          * `secGroups` (`pulumi.Input[str]`) - OpenStack comma separated security groups for the machine (string)
          * `sshPort` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh port. Default `22`. From Rancher v2.3.3 (string)
          * `sshUser` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh user. Default `docker`. From Rancher v2.3.3 (string)
          * `tenant_id` (`pulumi.Input[str]`) - OpenStack tenant id. Conflicts with `tenant_name` (string)
          * `tenantName` (`pulumi.Input[str]`) - OpenStack tenant name. Conflicts with `tenant_id` (string)
          * `userDataFile` (`pulumi.Input[str]`) - File containing an openstack userdata script (string)
          * `username` (`pulumi.Input[str]`) - vSphere username. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)

        The **vsphere_config** object supports the following:

          * `boot2dockerUrl` (`pulumi.Input[str]`) - vSphere URL for boot2docker iso image. Default `https://releases.rancher.com/os/latest/rancheros-vmware.iso` (string)
          * `cfgparams` (`pulumi.Input[list]`) - vSphere vm configuration parameters (used for guestinfo) (list)
          * `cloneFrom` (`pulumi.Input[str]`) - If you choose creation type clone a name of what you want to clone is required. From Rancher v2.3.3 (string)
          * `cloudConfig` (`pulumi.Input[str]`) - Filepath to a cloud-config yaml file to put into the ISO user-data. From Rancher v2.3.3 (string)
          * `cloudinit` (`pulumi.Input[str]`) - vSphere cloud-init file or url to set in the guestinfo (string)
          * `contentLibrary` (`pulumi.Input[str]`) - If you choose to clone from a content library template specify the name of the library. From Rancher v2.3.3 (string)
          * `cpuCount` (`pulumi.Input[str]`) - vSphere CPU number for docker VM. Default `2` (string)
          * `creationType` (`pulumi.Input[str]`) - Creation type when creating a new virtual machine. Supported values: vm, template, library, legacy. Default `legacy`. From Rancher v2.3.3 (string)
          * `customAttributes` (`pulumi.Input[list]`) - vSphere custom attributes, format key/value e.g. `200=my custom value`. From Rancher v2.3.3 (List)
          * `datacenter` (`pulumi.Input[str]`) - vSphere datacenter for docker VM (string)
          * `datastore` (`pulumi.Input[str]`) - vSphere datastore for docker VM (string)
          * `datastoreCluster` (`pulumi.Input[str]`) - vSphere datastore cluster for virtual machine. From Rancher v2.3.3 (string)
          * `diskSize` (`pulumi.Input[str]`) - vSphere size of disk for docker VM (in MB). Default `20480` (string)
          * `folder` (`pulumi.Input[str]`) - vSphere folder for the docker VM. This folder must already exist in the datacenter (string)
          * `hostsystem` (`pulumi.Input[str]`) - vSphere compute resource where the docker VM will be instantiated. This can be omitted if using a cluster with DRS (string)
          * `memorySize` (`pulumi.Input[str]`) - vSphere size of memory for docker VM (in MB). Default `2048` (string)
          * `networks` (`pulumi.Input[list]`) - vSphere network where the docker VM will be attached (list)
          * `password` (`pulumi.Input[str]`) - vSphere password. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `pool` (`pulumi.Input[str]`) - vSphere resource pool for docker VM (string)
          * `sshPassword` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh password. Default `tcuser`. From Rancher v2.3.3 (string)
          * `sshPort` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh port. Default `22`. From Rancher v2.3.3 (string)
          * `sshUser` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh user. Default `docker`. From Rancher v2.3.3 (string)
          * `sshUserGroup` (`pulumi.Input[str]`) - If using a non-B2D image the uploaded keys will need chown'ed. Default `staff`. From Rancher v2.3.3 (string)
          * `tags` (`pulumi.Input[list]`) - vSphere tags id e.g. `urn:xxx`. From Rancher v2.3.3 (list)
          * `username` (`pulumi.Input[str]`) - vSphere username. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `vappIpAllocationPolicy` (`pulumi.Input[str]`) - vSphere vApp IP allocation policy. Supported values are: `dhcp`, `fixed`, `transient` and `fixedAllocated` (string)
          * `vappIpProtocol` (`pulumi.Input[str]`) - vSphere vApp IP protocol for this deployment. Supported values are: `IPv4` and `IPv6` (string)
          * `vappProperties` (`pulumi.Input[list]`) - vSphere vApp properties (list)
          * `vappTransport` (`pulumi.Input[str]`) - vSphere OVF environment transports to use for properties. Supported values are: `iso` and `com.vmware.guestInfo` (string)
          * `vcenter` (`pulumi.Input[str]`) - vSphere IP/hostname for vCenter. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `vcenterPort` (`pulumi.Input[str]`) - vSphere Port for vCenter. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x. Default `443` (string)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['amazonec2_config'] = amazonec2_config
            __props__['annotations'] = annotations
            __props__['auth_certificate_authority'] = auth_certificate_authority
            __props__['auth_key'] = auth_key
            __props__['azure_config'] = azure_config
            __props__['cloud_credential_id'] = cloud_credential_id
            __props__['description'] = description
            __props__['digitalocean_config'] = digitalocean_config
            __props__['driver_id'] = driver_id
            __props__['engine_env'] = engine_env
            __props__['engine_insecure_registries'] = engine_insecure_registries
            __props__['engine_install_url'] = engine_install_url
            __props__['engine_label'] = engine_label
            __props__['engine_opt'] = engine_opt
            __props__['engine_registry_mirrors'] = engine_registry_mirrors
            __props__['engine_storage_driver'] = engine_storage_driver
            __props__['labels'] = labels
            __props__['linode_config'] = linode_config
            __props__['name'] = name
            __props__['opennebula_config'] = opennebula_config
            __props__['openstack_config'] = openstack_config
            __props__['use_internal_ip_address'] = use_internal_ip_address
            __props__['vsphere_config'] = vsphere_config
            __props__['driver'] = None
        super(NodeTemplate, __self__).__init__(
            'rancher2:index/nodeTemplate:NodeTemplate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, amazonec2_config=None, annotations=None, auth_certificate_authority=None, auth_key=None, azure_config=None, cloud_credential_id=None, description=None, digitalocean_config=None, driver=None, driver_id=None, engine_env=None, engine_insecure_registries=None, engine_install_url=None, engine_label=None, engine_opt=None, engine_registry_mirrors=None, engine_storage_driver=None, labels=None, linode_config=None, name=None, opennebula_config=None, openstack_config=None, use_internal_ip_address=None, vsphere_config=None):
        """
        Get an existing NodeTemplate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] amazonec2_config: AWS config for the Node Template (list maxitems:1)
        :param pulumi.Input[dict] annotations: Annotations for Node Template object (map)
        :param pulumi.Input[str] auth_certificate_authority: Auth certificate authority for the Node Template (string)
        :param pulumi.Input[str] auth_key: Auth key for the Node Template (string)
        :param pulumi.Input[dict] azure_config: Azure config for the Node Template (list maxitems:1)
        :param pulumi.Input[str] cloud_credential_id: Cloud credential ID for the Node Template. Required from Rancher v2.2.x (string)
        :param pulumi.Input[str] description: Description for the Node Template (string)
        :param pulumi.Input[dict] digitalocean_config: Digitalocean config for the Node Template (list maxitems:1)
        :param pulumi.Input[str] driver: (Computed) The driver of the node template (string)
        :param pulumi.Input[str] driver_id: The node driver id used by the node template. It's required if the node driver isn't built in Rancher (string)
        :param pulumi.Input[dict] engine_env: Engine environment for the node template (string)
        :param pulumi.Input[list] engine_insecure_registries: Insecure registry for the node template (list)
        :param pulumi.Input[str] engine_install_url: Docker engine install URL for the node template. Default `https://releases.rancher.com/install-docker/18.09.sh`. Available install docker versions at `https://github.com/rancher/install-docker` (string)
        :param pulumi.Input[dict] engine_label: Engine label for the node template (string)
        :param pulumi.Input[dict] engine_opt: Engine options for the node template (map)
        :param pulumi.Input[list] engine_registry_mirrors: Engine registry mirror for the node template (list)
        :param pulumi.Input[str] engine_storage_driver: Engine storage driver for the node template (string)
        :param pulumi.Input[dict] labels: Labels for Node Template object (map)
        :param pulumi.Input[dict] linode_config: Linode config for the Node Template (list maxitems:1)
        :param pulumi.Input[str] name: The name of the Node Template (string)
        :param pulumi.Input[dict] opennebula_config: Opennebula config for the Node Template (list maxitems:1)
        :param pulumi.Input[dict] openstack_config: Openstack config for the Node Template (list maxitems:1)
        :param pulumi.Input[bool] use_internal_ip_address: Engine storage driver for the node template (bool)
        :param pulumi.Input[dict] vsphere_config: vSphere config for the Node Template (list maxitems:1)

        The **amazonec2_config** object supports the following:

          * `access_key` (`pulumi.Input[str]`) - AWS access key. Required on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `ami` (`pulumi.Input[str]`) - AWS machine image (string)
          * `blockDurationMinutes` (`pulumi.Input[str]`) - AWS spot instance duration in minutes (60, 120, 180, 240, 300, or 360). Default `0` (string)
          * `deviceName` (`pulumi.Input[str]`) - AWS root device name. Default `/dev/sda1` (string)
          * `endpoint` (`pulumi.Input[str]`) - Optional endpoint URL (hostname only or fully qualified URI) (string)
          * `iamInstanceProfile` (`pulumi.Input[str]`) - AWS IAM Instance Profile (string)
          * `insecureTransport` (`pulumi.Input[bool]`) - Disable SSL when sending requests (bool)
          * `instanceType` (`pulumi.Input[str]`) - Specifies the Linode Instance type which determines CPU, memory, disk size, etc. Default `g6-standard-4` (string)
          * `keypairName` (`pulumi.Input[str]`) - OpenStack keypair to use to SSH to the instance (string)
          * `monitoring` (`pulumi.Input[bool]`) - Enable monitoring for droplet. Default `false` (bool)
          * `openPorts` (`pulumi.Input[list]`) - Make the specified port number accessible from the Internet. (list)
          * `privateAddressOnly` (`pulumi.Input[bool]`) - Only use a private IP address. Default `false` (bool)
          * `region` (`pulumi.Input[str]`) - OpenStack region name (string)
          * `requestSpotInstance` (`pulumi.Input[bool]`) - Set this flag to request spot instance. Default `false` (bool)
          * `retries` (`pulumi.Input[str]`) - Set retry count for recoverable failures (use -1 to disable). Default `5` (string)
          * `rootSize` (`pulumi.Input[str]`) - AWS root disk size (in GB). Default `16` (string)
          * `secret_key` (`pulumi.Input[str]`) - AWS secret key. Required on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `securityGroupReadonly` (`pulumi.Input[bool]`) - Skip adding default rules to security groups (bool)
          * `securityGroups` (`pulumi.Input[list]`) - AWS VPC security group. (list)
          * `sessionToken` (`pulumi.Input[str]`) - AWS Session Token (string)
          * `spotPrice` (`pulumi.Input[str]`) - AWS spot instance bid price (in dollar). Default `0.50` (string)
          * `sshKeypath` (`pulumi.Input[str]`) - SSH Key for Instance (string)
          * `sshUser` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh user. Default `docker`. From Rancher v2.3.3 (string)
          * `subnetId` (`pulumi.Input[str]`) - AWS VPC subnet id (string)
          * `tags` (`pulumi.Input[str]`) - vSphere tags id e.g. `urn:xxx`. From Rancher v2.3.3 (list)
          * `useEbsOptimizedInstance` (`pulumi.Input[bool]`) - Create an EBS optimized instance. Default `false` (bool)
          * `usePrivateAddress` (`pulumi.Input[bool]`) - Force the usage of private IP address. Default `false` (bool)
          * `userdata` (`pulumi.Input[str]`) - Path to file with cloud-init user-data (string)
          * `volumeType` (`pulumi.Input[str]`) - Amazon EBS volume type. Default `gp2` (string)
          * `vpcId` (`pulumi.Input[str]`) - AWS VPC id. (string)
          * `zone` (`pulumi.Input[str]`) - AWS zone for instance (i.e. a,b,c,d,e) (string)

        The **azure_config** object supports the following:

          * `availabilitySet` (`pulumi.Input[str]`) - Azure Availability Set to place the virtual machine into. Default `docker-machine` (string)
          * `client_id` (`pulumi.Input[str]`) - Azure Service Principal Account ID. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `client_secret` (`pulumi.Input[str]`) - Azure Service Principal Account password. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `customData` (`pulumi.Input[str]`) - Path to file with custom-data (string)
          * `diskSize` (`pulumi.Input[str]`) - vSphere size of disk for docker VM (in MB). Default `20480` (string)
          * `dns` (`pulumi.Input[str]`) - A unique DNS label for the public IP adddress (string)
          * `dockerPort` (`pulumi.Input[str]`) - Docker Port. Default `2376` (string)
          * `environment` (`pulumi.Input[str]`) - Azure environment (e.g. AzurePublicCloud, AzureChinaCloud). Default `AzurePublicCloud` (string)
            `fault_domain_count` - (Optional) Fault domain count to use for availability set. Default `3` (string)
          * `faultDomainCount` (`pulumi.Input[str]`)
          * `image` (`pulumi.Input[str]`) - Specifies the Linode Instance image which determines the OS distribution and base files. Default `linode/ubuntu18.04` (string)
          * `location` (`pulumi.Input[str]`) - Azure region to create the virtual machine. Default `westus` (string)
          * `managedDisks` (`pulumi.Input[bool]`) - Configures VM and availability set for managed disks. Just for Rancher v2.3.x and above. Default `false` (bool)
          * `noPublicIp` (`pulumi.Input[bool]`) - Do not create a public IP address for the machine. Default `false` (bool)
          * `openPorts` (`pulumi.Input[list]`) - Make the specified port number accessible from the Internet. (list)
          * `privateIpAddress` (`pulumi.Input[str]`) - Specify a static private IP address for the machine. (string)
          * `resourceGroup` (`pulumi.Input[str]`) - Azure Resource Group name (will be created if missing). Default `docker-machine` (string)
          * `size` (`pulumi.Input[str]`) - Digital Ocean size. Default `s-1vcpu-1gb` (string)
          * `sshUser` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh user. Default `docker`. From Rancher v2.3.3 (string)
          * `staticPublicIp` (`pulumi.Input[bool]`) - Assign a static public IP address to the machine. Default `false` (bool)
          * `storageType` (`pulumi.Input[str]`) - Type of Storage Account to host the OS Disk for the machine. Default `Standard_LRS` (string)
          * `subnet` (`pulumi.Input[str]`) - Azure Subnet Name to be used within the Virtual Network. Default `docker-machine` (string)
          * `subnetPrefix` (`pulumi.Input[str]`) - Private CIDR block to be used for the new subnet, should comply RFC 1918. Default `192.168.0.0/16` (string)
          * `subscriptionId` (`pulumi.Input[str]`) - Azure Subscription ID. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `updateDomainCount` (`pulumi.Input[str]`) - Update domain count to use for availability set. Default `5` (string)
          * `usePrivateIp` (`pulumi.Input[bool]`) - Use private IP address of the machine to connect. Default `false` (bool)
          * `vnet` (`pulumi.Input[str]`) - Azure Virtual Network name to connect the virtual machine (in [resourcegroup:]name format). Default `docker-machine-vnet` (string)

        The **digitalocean_config** object supports the following:

          * `accessToken` (`pulumi.Input[str]`) - Digital Ocean access token. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `backups` (`pulumi.Input[bool]`) - Enable backups for droplet. Default `false` (bool)
          * `image` (`pulumi.Input[str]`) - Specifies the Linode Instance image which determines the OS distribution and base files. Default `linode/ubuntu18.04` (string)
          * `ipv6` (`pulumi.Input[bool]`) - Enable ipv6 for droplet. Default `false` (bool)
          * `monitoring` (`pulumi.Input[bool]`) - Enable monitoring for droplet. Default `false` (bool)
          * `privateNetworking` (`pulumi.Input[bool]`) - Enable private networking for droplet. Default `false` (bool)
          * `region` (`pulumi.Input[str]`) - OpenStack region name (string)
          * `size` (`pulumi.Input[str]`) - Digital Ocean size. Default `s-1vcpu-1gb` (string)
          * `sshKeyFingerprint` (`pulumi.Input[str]`) - SSH key fingerprint (string)
          * `sshKeyPath` (`pulumi.Input[str]`) - SSH private key path (string)
          * `sshPort` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh port. Default `22`. From Rancher v2.3.3 (string)
          * `sshUser` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh user. Default `docker`. From Rancher v2.3.3 (string)
          * `tags` (`pulumi.Input[str]`) - vSphere tags id e.g. `urn:xxx`. From Rancher v2.3.3 (list)
          * `userdata` (`pulumi.Input[str]`) - Path to file with cloud-init user-data (string)

        The **linode_config** object supports the following:

          * `authorizedUsers` (`pulumi.Input[str]`) - Linode user accounts (seperated by commas) whose Linode SSH keys will be permitted root access to the created node. (string)
          * `createPrivateIp` (`pulumi.Input[bool]`) - Create private IP for the instance. Default `false` (bool)
          * `dockerPort` (`pulumi.Input[str]`) - Docker Port. Default `2376` (string)
          * `image` (`pulumi.Input[str]`) - Specifies the Linode Instance image which determines the OS distribution and base files. Default `linode/ubuntu18.04` (string)
          * `instanceType` (`pulumi.Input[str]`) - Specifies the Linode Instance type which determines CPU, memory, disk size, etc. Default `g6-standard-4` (string)
          * `label` (`pulumi.Input[str]`) - Linode Instance Label. (string)
          * `region` (`pulumi.Input[str]`) - OpenStack region name (string)
          * `rootPass` (`pulumi.Input[str]`) - Root Password (string)
          * `sshPort` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh port. Default `22`. From Rancher v2.3.3 (string)
          * `sshUser` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh user. Default `docker`. From Rancher v2.3.3 (string)
          * `stackscript` (`pulumi.Input[str]`) - Specifies the Linode StackScript to use to create the instance. (string)
          * `stackscriptData` (`pulumi.Input[str]`) - A JSON string specifying data for the selected StackScript. (string)
          * `swapSize` (`pulumi.Input[str]`) - Linode Instance Swap Size (MB). Default `512` (string)
          * `tags` (`pulumi.Input[str]`) - vSphere tags id e.g. `urn:xxx`. From Rancher v2.3.3 (list)
          * `token` (`pulumi.Input[str]`) - Linode API token. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `uaPrefix` (`pulumi.Input[str]`) - Prefix the User-Agent in Linode API calls with some 'product/version' (string)

        The **opennebula_config** object supports the following:

          * `b2dSize` (`pulumi.Input[str]`) - Size of the Volatile disk in MB - only for b2d (string)
          * `cpu` (`pulumi.Input[str]`) - CPU value for the VM (string)
          * `devPrefix` (`pulumi.Input[str]`) - Dev prefix to use for the images. E.g.: 'vd', 'sd', 'hd' (string)
          * `disableVnc` (`pulumi.Input[bool]`) - VNC is enabled by default. Disable it with this flag (bool)
          * `diskResize` (`pulumi.Input[str]`) - Size of the disk for the VM in MB (string)
          * `imageId` (`pulumi.Input[str]`) - OpenStack image id to use for the instance. Conflicts with `image_name` (string)
          * `imageName` (`pulumi.Input[str]`) - OpenStack image name to use for the instance. Conflicts with `image_id` (string)
          * `imageOwner` (`pulumi.Input[str]`) - Owner of the image to use as the VM OS (string)
          * `memory` (`pulumi.Input[str]`) - Size of the memory for the VM in MB (string)
          * `networkId` (`pulumi.Input[str]`) - Opennebula network ID to connect the machine to. Conflicts with `network_name` (string)
          * `networkName` (`pulumi.Input[str]`) - Opennebula network to connect the machine to. Conflicts with `network_id` (string)
          * `networkOwner` (`pulumi.Input[str]`) - Opennebula user ID of the Network to connect the machine to (string)
          * `password` (`pulumi.Input[str]`) - vSphere password. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `sshUser` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh user. Default `docker`. From Rancher v2.3.3 (string)
          * `templateId` (`pulumi.Input[str]`) - Opennebula template ID to use. Conflicts with `template_name` (string)
          * `template_name` (`pulumi.Input[str]`) - Name of the Opennbula template to use. Conflicts with `template_id` (string)
          * `user` (`pulumi.Input[str]`) - Set the user for the XML-RPC API authentication (string)
          * `vcpu` (`pulumi.Input[str]`) - VCPUs for the VM (string)
          * `xmlRpcUrl` (`pulumi.Input[str]`) - Set the url for the Opennebula XML-RPC API (string)

        The **openstack_config** object supports the following:

          * `activeTimeout` (`pulumi.Input[str]`) - OpenStack active timeout Default `200` (string)
          * `authUrl` (`pulumi.Input[str]`) - OpenStack authentication URL (string)
          * `availabilityZone` (`pulumi.Input[str]`) - OpenStack availability zone (string)
          * `cacert` (`pulumi.Input[str]`) - CA certificate bundle to verify against (string)
          * `configDrive` (`pulumi.Input[bool]`) - Enables the OpenStack config drive for the instance. Default `false` (bool)
          * `domainId` (`pulumi.Input[str]`) - OpenStack domain ID. Identity v3 only. Conflicts with `domain_name` (string)
          * `domainName` (`pulumi.Input[str]`) - OpenStack domain name. Identity v3 only. Conflicts with `domain_id` (string)
          * `endpointType` (`pulumi.Input[str]`) - OpenStack endpoint type. adminURL, internalURL or publicURL (string)
          * `flavorId` (`pulumi.Input[str]`) - OpenStack flavor id to use for the instance. Conflicts with `flavor_name` (string)
          * `flavorName` (`pulumi.Input[str]`) - OpenStack flavor name to use for the instance. Conflicts with `flavor_id` (string)
          * `floatingIpPool` (`pulumi.Input[str]`) - OpenStack floating IP pool to get an IP from to assign to the instance (string)
          * `imageId` (`pulumi.Input[str]`) - OpenStack image id to use for the instance. Conflicts with `image_name` (string)
          * `imageName` (`pulumi.Input[str]`) - OpenStack image name to use for the instance. Conflicts with `image_id` (string)
          * `insecure` (`pulumi.Input[bool]`) - Disable TLS credential checking. Default `false` (bool)
          * `ipVersion` (`pulumi.Input[str]`) - OpenStack version of IP address assigned for the machine Default `4` (string)
          * `keypairName` (`pulumi.Input[str]`) - OpenStack keypair to use to SSH to the instance (string)
          * `netId` (`pulumi.Input[str]`) - OpenStack network id the machine will be connected on. Conflicts with `net_name` (string)
          * `netName` (`pulumi.Input[str]`) - OpenStack network name the machine will be connected on. Conflicts with `net_id` (string)
          * `novaNetwork` (`pulumi.Input[bool]`) - Use the nova networking services instead of neutron (string)
          * `password` (`pulumi.Input[str]`) - vSphere password. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `privateKeyFile` (`pulumi.Input[str]`) - Private key content to use for SSH (string)
          * `region` (`pulumi.Input[str]`) - OpenStack region name (string)
          * `secGroups` (`pulumi.Input[str]`) - OpenStack comma separated security groups for the machine (string)
          * `sshPort` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh port. Default `22`. From Rancher v2.3.3 (string)
          * `sshUser` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh user. Default `docker`. From Rancher v2.3.3 (string)
          * `tenant_id` (`pulumi.Input[str]`) - OpenStack tenant id. Conflicts with `tenant_name` (string)
          * `tenantName` (`pulumi.Input[str]`) - OpenStack tenant name. Conflicts with `tenant_id` (string)
          * `userDataFile` (`pulumi.Input[str]`) - File containing an openstack userdata script (string)
          * `username` (`pulumi.Input[str]`) - vSphere username. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)

        The **vsphere_config** object supports the following:

          * `boot2dockerUrl` (`pulumi.Input[str]`) - vSphere URL for boot2docker iso image. Default `https://releases.rancher.com/os/latest/rancheros-vmware.iso` (string)
          * `cfgparams` (`pulumi.Input[list]`) - vSphere vm configuration parameters (used for guestinfo) (list)
          * `cloneFrom` (`pulumi.Input[str]`) - If you choose creation type clone a name of what you want to clone is required. From Rancher v2.3.3 (string)
          * `cloudConfig` (`pulumi.Input[str]`) - Filepath to a cloud-config yaml file to put into the ISO user-data. From Rancher v2.3.3 (string)
          * `cloudinit` (`pulumi.Input[str]`) - vSphere cloud-init file or url to set in the guestinfo (string)
          * `contentLibrary` (`pulumi.Input[str]`) - If you choose to clone from a content library template specify the name of the library. From Rancher v2.3.3 (string)
          * `cpuCount` (`pulumi.Input[str]`) - vSphere CPU number for docker VM. Default `2` (string)
          * `creationType` (`pulumi.Input[str]`) - Creation type when creating a new virtual machine. Supported values: vm, template, library, legacy. Default `legacy`. From Rancher v2.3.3 (string)
          * `customAttributes` (`pulumi.Input[list]`) - vSphere custom attributes, format key/value e.g. `200=my custom value`. From Rancher v2.3.3 (List)
          * `datacenter` (`pulumi.Input[str]`) - vSphere datacenter for docker VM (string)
          * `datastore` (`pulumi.Input[str]`) - vSphere datastore for docker VM (string)
          * `datastoreCluster` (`pulumi.Input[str]`) - vSphere datastore cluster for virtual machine. From Rancher v2.3.3 (string)
          * `diskSize` (`pulumi.Input[str]`) - vSphere size of disk for docker VM (in MB). Default `20480` (string)
          * `folder` (`pulumi.Input[str]`) - vSphere folder for the docker VM. This folder must already exist in the datacenter (string)
          * `hostsystem` (`pulumi.Input[str]`) - vSphere compute resource where the docker VM will be instantiated. This can be omitted if using a cluster with DRS (string)
          * `memorySize` (`pulumi.Input[str]`) - vSphere size of memory for docker VM (in MB). Default `2048` (string)
          * `networks` (`pulumi.Input[list]`) - vSphere network where the docker VM will be attached (list)
          * `password` (`pulumi.Input[str]`) - vSphere password. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `pool` (`pulumi.Input[str]`) - vSphere resource pool for docker VM (string)
          * `sshPassword` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh password. Default `tcuser`. From Rancher v2.3.3 (string)
          * `sshPort` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh port. Default `22`. From Rancher v2.3.3 (string)
          * `sshUser` (`pulumi.Input[str]`) - If using a non-B2D image you can specify the ssh user. Default `docker`. From Rancher v2.3.3 (string)
          * `sshUserGroup` (`pulumi.Input[str]`) - If using a non-B2D image the uploaded keys will need chown'ed. Default `staff`. From Rancher v2.3.3 (string)
          * `tags` (`pulumi.Input[list]`) - vSphere tags id e.g. `urn:xxx`. From Rancher v2.3.3 (list)
          * `username` (`pulumi.Input[str]`) - vSphere username. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `vappIpAllocationPolicy` (`pulumi.Input[str]`) - vSphere vApp IP allocation policy. Supported values are: `dhcp`, `fixed`, `transient` and `fixedAllocated` (string)
          * `vappIpProtocol` (`pulumi.Input[str]`) - vSphere vApp IP protocol for this deployment. Supported values are: `IPv4` and `IPv6` (string)
          * `vappProperties` (`pulumi.Input[list]`) - vSphere vApp properties (list)
          * `vappTransport` (`pulumi.Input[str]`) - vSphere OVF environment transports to use for properties. Supported values are: `iso` and `com.vmware.guestInfo` (string)
          * `vcenter` (`pulumi.Input[str]`) - vSphere IP/hostname for vCenter. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x (string)
          * `vcenterPort` (`pulumi.Input[str]`) - vSphere Port for vCenter. Mandatory on Rancher v2.0.x and v2.1.x. Use `.CloudCredential` from Rancher v2.2.x. Default `443` (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["amazonec2_config"] = amazonec2_config
        __props__["annotations"] = annotations
        __props__["auth_certificate_authority"] = auth_certificate_authority
        __props__["auth_key"] = auth_key
        __props__["azure_config"] = azure_config
        __props__["cloud_credential_id"] = cloud_credential_id
        __props__["description"] = description
        __props__["digitalocean_config"] = digitalocean_config
        __props__["driver"] = driver
        __props__["driver_id"] = driver_id
        __props__["engine_env"] = engine_env
        __props__["engine_insecure_registries"] = engine_insecure_registries
        __props__["engine_install_url"] = engine_install_url
        __props__["engine_label"] = engine_label
        __props__["engine_opt"] = engine_opt
        __props__["engine_registry_mirrors"] = engine_registry_mirrors
        __props__["engine_storage_driver"] = engine_storage_driver
        __props__["labels"] = labels
        __props__["linode_config"] = linode_config
        __props__["name"] = name
        __props__["opennebula_config"] = opennebula_config
        __props__["openstack_config"] = openstack_config
        __props__["use_internal_ip_address"] = use_internal_ip_address
        __props__["vsphere_config"] = vsphere_config
        return NodeTemplate(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import importlib
# Make subpackages available:
__all__ = ['config']
for pkg in __all__:
    if pkg != 'config':
        importlib.import_module(f'{__name__}.{pkg}')

# Export this package's modules as members:
from .active_directory import *
from .app import *
from .auth_config_adfs import *
from .auth_config_azure_ad import *
from .auth_config_free_ipa import *
from .auth_config_github import *
from .auth_config_keycloak import *
from .auth_config_okta import *
from .auth_config_open_ldap import *
from .auth_config_ping import *
from .bootstrap import *
from .catalog import *
from .certificate import *
from .cloud_credential import *
from .cluster import *
from .cluster_alter_group import *
from .cluster_alter_rule import *
from .cluster_driver import *
from .cluster_logging import *
from .cluster_role_template_binding import *
from .cluster_sync import *
from .cluster_template import *
from .etcd_backup import *
from .get_app import *
from .get_catalog import *
from .get_certificate import *
from .get_cloud_credential import *
from .get_cluster import *
from .get_cluster_alert_group import *
from .get_cluster_alter_rule import *
from .get_cluster_driver import *
from .get_cluster_logging import *
from .get_cluster_role_template_binding import *
from .get_cluster_scan import *
from .get_cluster_template import *
from .get_etcd_backup import *
from .get_global_role_binding import *
from .get_multi_cluster_app import *
from .get_namespace import *
from .get_node_driver import *
from .get_node_pool import *
from .get_node_template import *
from .get_notifier import *
from .get_pod_security_policy_template import *
from .get_project import *
from .get_project_alert_group import *
from .get_project_alert_rule import *
from .get_project_logging import *
from .get_project_role_template_binding import *
from .get_registry import *
from .get_role_tempalte import *
from .get_role_template import *
from .get_secret import *
from .get_setting import *
from .get_user import *
from .global_role_binding import *
from .multi_cluster_app import *
from .namespace import *
from .node_driver import *
from .node_pool import *
from .node_template import *
from .notifier import *
from .pod_security_policy_template import *
from .project import *
from .project_alert_group import *
from .project_alert_rule import *
from .project_logging import *
from .project_role_template_binding import *
from .provider import *
from .registry import *
from .role_tempalte import *
from .secret import *
from .setting import *
from .token import *
from .user import *



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetMultiClusterAppResult:
    """
    A collection of values returned by getMultiClusterApp.
    """
    def __init__(__self__, annotations=None, answers=None, catalog_name=None, id=None, labels=None, members=None, name=None, revision_history_limit=None, revision_id=None, roles=None, targets=None, template_name=None, template_version=None, template_version_id=None, upgrade_strategies=None):
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        __self__.annotations = annotations
        """
        (Computed) Annotations for multi cluster app object (map)
        """
        if answers and not isinstance(answers, list):
            raise TypeError("Expected argument 'answers' to be a list")
        __self__.answers = answers
        """
        (Computed) The multi cluster app answers (list)
        """
        if catalog_name and not isinstance(catalog_name, str):
            raise TypeError("Expected argument 'catalog_name' to be a str")
        __self__.catalog_name = catalog_name
        """
        (Computed) The multi cluster app catalog name (string)
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        """
        (Computed) Labels for multi cluster app object (map)
        """
        if members and not isinstance(members, list):
            raise TypeError("Expected argument 'members' to be a list")
        __self__.members = members
        """
        (Computed) The multi cluster app members (list)
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if revision_history_limit and not isinstance(revision_history_limit, float):
            raise TypeError("Expected argument 'revision_history_limit' to be a float")
        __self__.revision_history_limit = revision_history_limit
        """
        (Computed) The multi cluster app revision history limit (int)
        """
        if revision_id and not isinstance(revision_id, str):
            raise TypeError("Expected argument 'revision_id' to be a str")
        __self__.revision_id = revision_id
        """
        (Computed) Current revision id for the multi cluster app (string)
        """
        if roles and not isinstance(roles, list):
            raise TypeError("Expected argument 'roles' to be a list")
        __self__.roles = roles
        """
        (Computed) The multi cluster app roles (list)
        """
        if targets and not isinstance(targets, list):
            raise TypeError("Expected argument 'targets' to be a list")
        __self__.targets = targets
        """
        (Computed) The multi cluster app target projects (list)
        """
        if template_name and not isinstance(template_name, str):
            raise TypeError("Expected argument 'template_name' to be a str")
        __self__.template_name = template_name
        """
        (Computed) The multi cluster app template name (string)
        """
        if template_version and not isinstance(template_version, str):
            raise TypeError("Expected argument 'template_version' to be a str")
        __self__.template_version = template_version
        """
        (Computed) The multi cluster app template version (string)
        """
        if template_version_id and not isinstance(template_version_id, str):
            raise TypeError("Expected argument 'template_version_id' to be a str")
        __self__.template_version_id = template_version_id
        """
        (Computed) The multi cluster app template version ID (string)
        """
        if upgrade_strategies and not isinstance(upgrade_strategies, list):
            raise TypeError("Expected argument 'upgrade_strategies' to be a list")
        __self__.upgrade_strategies = upgrade_strategies
        """
        (Computed) The multi cluster app upgrade strategy (list)
        """
class AwaitableGetMultiClusterAppResult(GetMultiClusterAppResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMultiClusterAppResult(
            annotations=self.annotations,
            answers=self.answers,
            catalog_name=self.catalog_name,
            id=self.id,
            labels=self.labels,
            members=self.members,
            name=self.name,
            revision_history_limit=self.revision_history_limit,
            revision_id=self.revision_id,
            roles=self.roles,
            targets=self.targets,
            template_name=self.template_name,
            template_version=self.template_version,
            template_version_id=self.template_version_id,
            upgrade_strategies=self.upgrade_strategies)

def get_multi_cluster_app(name=None,opts=None):
    """
    Use this data source to retrieve information about a Rancher v2 multi cluster app.




    :param str name: The multi cluster app name (string)
    """
    __args__ = dict()


    __args__['name'] = name
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('rancher2:index/getMultiClusterApp:getMultiClusterApp', __args__, opts=opts).value

    return AwaitableGetMultiClusterAppResult(
        annotations=__ret__.get('annotations'),
        answers=__ret__.get('answers'),
        catalog_name=__ret__.get('catalogName'),
        id=__ret__.get('id'),
        labels=__ret__.get('labels'),
        members=__ret__.get('members'),
        name=__ret__.get('name'),
        revision_history_limit=__ret__.get('revisionHistoryLimit'),
        revision_id=__ret__.get('revisionId'),
        roles=__ret__.get('roles'),
        targets=__ret__.get('targets'),
        template_name=__ret__.get('templateName'),
        template_version=__ret__.get('templateVersion'),
        template_version_id=__ret__.get('templateVersionId'),
        upgrade_strategies=__ret__.get('upgradeStrategies'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetClusterTemplateResult:
    """
    A collection of values returned by getClusterTemplate.
    """
    def __init__(__self__, annotations=None, default_revision_id=None, description=None, id=None, labels=None, members=None, name=None, template_revisions=None):
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        __self__.annotations = annotations
        """
        (Computed) Annotations for the cluster template (map)
        """
        if default_revision_id and not isinstance(default_revision_id, str):
            raise TypeError("Expected argument 'default_revision_id' to be a str")
        __self__.default_revision_id = default_revision_id
        """
        (Computed) Default cluster template revision ID (string)
        """
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        __self__.description = description
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        """
        (Computed) Labels for the cluster template (map)
        """
        if members and not isinstance(members, list):
            raise TypeError("Expected argument 'members' to be a list")
        __self__.members = members
        """
        (Computed) Cluster template members (list)
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if template_revisions and not isinstance(template_revisions, list):
            raise TypeError("Expected argument 'template_revisions' to be a list")
        __self__.template_revisions = template_revisions
        """
        (Computed) Cluster template revisions (list)
        """
class AwaitableGetClusterTemplateResult(GetClusterTemplateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetClusterTemplateResult(
            annotations=self.annotations,
            default_revision_id=self.default_revision_id,
            description=self.description,
            id=self.id,
            labels=self.labels,
            members=self.members,
            name=self.name,
            template_revisions=self.template_revisions)

def get_cluster_template(annotations=None,description=None,labels=None,name=None,opts=None):
    """
    Use this data source to retrieve information about a Rancher v2 cluster template.

    Cluster Templates are available from Rancher v2.3.x and above.




    :param dict annotations: (Computed) Annotations for the cluster template (map)
    :param dict labels: (Computed) Labels for the cluster template (map)
    :param str name: The cluster template name (string)
    """
    __args__ = dict()


    __args__['annotations'] = annotations
    __args__['description'] = description
    __args__['labels'] = labels
    __args__['name'] = name
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('rancher2:index/getClusterTemplate:getClusterTemplate', __args__, opts=opts).value

    return AwaitableGetClusterTemplateResult(
        annotations=__ret__.get('annotations'),
        default_revision_id=__ret__.get('defaultRevisionId'),
        description=__ret__.get('description'),
        id=__ret__.get('id'),
        labels=__ret__.get('labels'),
        members=__ret__.get('members'),
        name=__ret__.get('name'),
        template_revisions=__ret__.get('templateRevisions'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class Bootstrap(pulumi.CustomResource):
    current_password: pulumi.Output[str]
    """
    Current password for Admin user. Just needed for recover if admin password has been changed from other resources and token is expired (string)
    """
    password: pulumi.Output[str]
    """
    Password for Admin user or random generated if empty (string)
    """
    telemetry: pulumi.Output[bool]
    """
    Send telemetry anonymous data. Default: `false` (bool)
    """
    temp_token: pulumi.Output[str]
    """
    (Computed) Generated API temporary token as helper. Should be empty (string)
    """
    temp_token_id: pulumi.Output[str]
    """
    (Computed) Generated API temporary token id as helper. Should be empty (string)
    """
    token: pulumi.Output[str]
    """
    (Computed) Generated API token for Admin User (string)
    """
    token_id: pulumi.Output[str]
    """
    (Computed) Generated API token id for Admin User (string)
    """
    token_ttl: pulumi.Output[float]
    """
    TTL in seconds for generated admin token. Default: `0`  (int)
    """
    token_update: pulumi.Output[bool]
    """
    Regenerate admin token. Default: `false` (bool)
    """
    url: pulumi.Output[str]
    """
    (Computed) URL set as server-url (string)
    """
    user: pulumi.Output[str]
    """
    (Computed) Admin username (string)
    """
    def __init__(__self__, resource_name, opts=None, current_password=None, password=None, telemetry=None, token_ttl=None, token_update=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a Bootstrap resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] current_password: Current password for Admin user. Just needed for recover if admin password has been changed from other resources and token is expired (string)
        :param pulumi.Input[str] password: Password for Admin user or random generated if empty (string)
        :param pulumi.Input[bool] telemetry: Send telemetry anonymous data. Default: `false` (bool)
        :param pulumi.Input[float] token_ttl: TTL in seconds for generated admin token. Default: `0`  (int)
        :param pulumi.Input[bool] token_update: Regenerate admin token. Default: `false` (bool)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['current_password'] = current_password
            __props__['password'] = password
            __props__['telemetry'] = telemetry
            __props__['token_ttl'] = token_ttl
            __props__['token_update'] = token_update
            __props__['temp_token'] = None
            __props__['temp_token_id'] = None
            __props__['token'] = None
            __props__['token_id'] = None
            __props__['url'] = None
            __props__['user'] = None
        super(Bootstrap, __self__).__init__(
            'rancher2:index/bootstrap:Bootstrap',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, current_password=None, password=None, telemetry=None, temp_token=None, temp_token_id=None, token=None, token_id=None, token_ttl=None, token_update=None, url=None, user=None):
        """
        Get an existing Bootstrap resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] current_password: Current password for Admin user. Just needed for recover if admin password has been changed from other resources and token is expired (string)
        :param pulumi.Input[str] password: Password for Admin user or random generated if empty (string)
        :param pulumi.Input[bool] telemetry: Send telemetry anonymous data. Default: `false` (bool)
        :param pulumi.Input[str] temp_token: (Computed) Generated API temporary token as helper. Should be empty (string)
        :param pulumi.Input[str] temp_token_id: (Computed) Generated API temporary token id as helper. Should be empty (string)
        :param pulumi.Input[str] token: (Computed) Generated API token for Admin User (string)
        :param pulumi.Input[str] token_id: (Computed) Generated API token id for Admin User (string)
        :param pulumi.Input[float] token_ttl: TTL in seconds for generated admin token. Default: `0`  (int)
        :param pulumi.Input[bool] token_update: Regenerate admin token. Default: `false` (bool)
        :param pulumi.Input[str] url: (Computed) URL set as server-url (string)
        :param pulumi.Input[str] user: (Computed) Admin username (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["current_password"] = current_password
        __props__["password"] = password
        __props__["telemetry"] = telemetry
        __props__["temp_token"] = temp_token
        __props__["temp_token_id"] = temp_token_id
        __props__["token"] = token
        __props__["token_id"] = token_id
        __props__["token_ttl"] = token_ttl
        __props__["token_update"] = token_update
        __props__["url"] = url
        __props__["user"] = user
        return Bootstrap(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class ProjectAlertGroup(pulumi.CustomResource):
    annotations: pulumi.Output[dict]
    """
    The project alert group annotations (map)
    """
    description: pulumi.Output[str]
    """
    The project alert group description (string)
    """
    group_interval_seconds: pulumi.Output[float]
    """
    The project alert group interval seconds. Default: `180` (int)
    """
    group_wait_seconds: pulumi.Output[float]
    """
    The project alert group wait seconds. Default: `180` (int)
    """
    labels: pulumi.Output[dict]
    """
    The project alert group labels (map)
    """
    name: pulumi.Output[str]
    """
    The project alert group name (string)
    """
    project_id: pulumi.Output[str]
    """
    The project id where create project alert group (string)
    """
    recipients: pulumi.Output[list]
    """
    The project alert group recipients (list)

      * `defaultRecipient` (`bool`)
      * `notifierId` (`str`) - Recipient notifier ID (string)
      * `notifierType` (`str`) - Recipient notifier ID. Supported values : `"pagerduty" | "slack" | "email" | "webhook" | "wechat"` (string)
      * `recipient` (`str`) - Recipient (string)
    """
    repeat_interval_seconds: pulumi.Output[float]
    """
    The project alert group wait seconds. Default: `3600` (int)
    """
    def __init__(__self__, resource_name, opts=None, annotations=None, description=None, group_interval_seconds=None, group_wait_seconds=None, labels=None, name=None, project_id=None, recipients=None, repeat_interval_seconds=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Rancher v2 Project Alert Group resource. This can be used to create Project Alert Group for Rancher v2 environments and retrieve their information.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: The project alert group annotations (map)
        :param pulumi.Input[str] description: The project alert group description (string)
        :param pulumi.Input[float] group_interval_seconds: The project alert group interval seconds. Default: `180` (int)
        :param pulumi.Input[float] group_wait_seconds: The project alert group wait seconds. Default: `180` (int)
        :param pulumi.Input[dict] labels: The project alert group labels (map)
        :param pulumi.Input[str] name: The project alert group name (string)
        :param pulumi.Input[str] project_id: The project id where create project alert group (string)
        :param pulumi.Input[list] recipients: The project alert group recipients (list)
        :param pulumi.Input[float] repeat_interval_seconds: The project alert group wait seconds. Default: `3600` (int)

        The **recipients** object supports the following:

          * `defaultRecipient` (`pulumi.Input[bool]`)
          * `notifierId` (`pulumi.Input[str]`) - Recipient notifier ID (string)
          * `notifierType` (`pulumi.Input[str]`) - Recipient notifier ID. Supported values : `"pagerduty" | "slack" | "email" | "webhook" | "wechat"` (string)
          * `recipient` (`pulumi.Input[str]`) - Recipient (string)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['annotations'] = annotations
            __props__['description'] = description
            __props__['group_interval_seconds'] = group_interval_seconds
            __props__['group_wait_seconds'] = group_wait_seconds
            __props__['labels'] = labels
            __props__['name'] = name
            if project_id is None:
                raise TypeError("Missing required property 'project_id'")
            __props__['project_id'] = project_id
            __props__['recipients'] = recipients
            __props__['repeat_interval_seconds'] = repeat_interval_seconds
        super(ProjectAlertGroup, __self__).__init__(
            'rancher2:index/projectAlertGroup:ProjectAlertGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, annotations=None, description=None, group_interval_seconds=None, group_wait_seconds=None, labels=None, name=None, project_id=None, recipients=None, repeat_interval_seconds=None):
        """
        Get an existing ProjectAlertGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: The project alert group annotations (map)
        :param pulumi.Input[str] description: The project alert group description (string)
        :param pulumi.Input[float] group_interval_seconds: The project alert group interval seconds. Default: `180` (int)
        :param pulumi.Input[float] group_wait_seconds: The project alert group wait seconds. Default: `180` (int)
        :param pulumi.Input[dict] labels: The project alert group labels (map)
        :param pulumi.Input[str] name: The project alert group name (string)
        :param pulumi.Input[str] project_id: The project id where create project alert group (string)
        :param pulumi.Input[list] recipients: The project alert group recipients (list)
        :param pulumi.Input[float] repeat_interval_seconds: The project alert group wait seconds. Default: `3600` (int)

        The **recipients** object supports the following:

          * `defaultRecipient` (`pulumi.Input[bool]`)
          * `notifierId` (`pulumi.Input[str]`) - Recipient notifier ID (string)
          * `notifierType` (`pulumi.Input[str]`) - Recipient notifier ID. Supported values : `"pagerduty" | "slack" | "email" | "webhook" | "wechat"` (string)
          * `recipient` (`pulumi.Input[str]`) - Recipient (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["annotations"] = annotations
        __props__["description"] = description
        __props__["group_interval_seconds"] = group_interval_seconds
        __props__["group_wait_seconds"] = group_wait_seconds
        __props__["labels"] = labels
        __props__["name"] = name
        __props__["project_id"] = project_id
        __props__["recipients"] = recipients
        __props__["repeat_interval_seconds"] = repeat_interval_seconds
        return ProjectAlertGroup(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetClusterScanResult:
    """
    A collection of values returned by getClusterScan.
    """
    def __init__(__self__, annotations=None, cluster_id=None, id=None, labels=None, name=None, run_type=None, scan_config=None, scan_type=None, status=None):
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        __self__.annotations = annotations
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        __self__.cluster_id = cluster_id
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if run_type and not isinstance(run_type, str):
            raise TypeError("Expected argument 'run_type' to be a str")
        __self__.run_type = run_type
        if scan_config and not isinstance(scan_config, dict):
            raise TypeError("Expected argument 'scan_config' to be a dict")
        __self__.scan_config = scan_config
        if scan_type and not isinstance(scan_type, str):
            raise TypeError("Expected argument 'scan_type' to be a str")
        __self__.scan_type = scan_type
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        __self__.status = status
class AwaitableGetClusterScanResult(GetClusterScanResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetClusterScanResult(
            annotations=self.annotations,
            cluster_id=self.cluster_id,
            id=self.id,
            labels=self.labels,
            name=self.name,
            run_type=self.run_type,
            scan_config=self.scan_config,
            scan_type=self.scan_type,
            status=self.status)

def get_cluster_scan(cluster_id=None,name=None,opts=None):
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()


    __args__['clusterId'] = cluster_id
    __args__['name'] = name
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('rancher2:index/getClusterScan:getClusterScan', __args__, opts=opts).value

    return AwaitableGetClusterScanResult(
        annotations=__ret__.get('annotations'),
        cluster_id=__ret__.get('clusterId'),
        id=__ret__.get('id'),
        labels=__ret__.get('labels'),
        name=__ret__.get('name'),
        run_type=__ret__.get('runType'),
        scan_config=__ret__.get('scanConfig'),
        scan_type=__ret__.get('scanType'),
        status=__ret__.get('status'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class CloudCredential(pulumi.CustomResource):
    amazonec2_credential_config: pulumi.Output[dict]
    """
    AWS config for the Cloud Credential (list maxitems:1)

      * `access_key` (`str`) - AWS access key (string)
      * `secret_key` (`str`) - AWS secret key (string)
    """
    annotations: pulumi.Output[dict]
    """
    Annotations for Cloud Credential object (map)
    """
    azure_credential_config: pulumi.Output[dict]
    """
    Azure config for the Cloud Credential (list maxitems:1)

      * `client_id` (`str`) - Azure Service Principal Account ID (string)
      * `client_secret` (`str`) - Azure Service Principal Account password (string)
      * `subscriptionId` (`str`) - Azure Subscription ID (string)
    """
    description: pulumi.Output[str]
    """
    Description for the Cloud Credential (string)
    """
    digitalocean_credential_config: pulumi.Output[dict]
    """
    DigitalOcean config for the Cloud Credential (list maxitems:1)

      * `accessToken` (`str`) - DigitalOcean access token (string)
    """
    driver: pulumi.Output[str]
    """
    (Computed) The driver of the Cloud Credential (string)
    """
    labels: pulumi.Output[dict]
    """
    Labels for Cloud Credential object (map)
    """
    linode_credential_config: pulumi.Output[dict]
    """
    Linode config for the Cloud Credential (list maxitems:1)

      * `token` (`str`) - Linode API token (string)
    """
    name: pulumi.Output[str]
    """
    The name of the Cloud Credential (string)
    """
    openstack_credential_config: pulumi.Output[dict]
    """
    OpenStack config for the Cloud Credential (list maxitems:1)

      * `password` (`str`) - vSphere password (string)
    """
    vsphere_credential_config: pulumi.Output[dict]
    """
    vSphere config for the Cloud Credential (list maxitems:1)

      * `password` (`str`) - vSphere password (string)
      * `username` (`str`) - vSphere username (string)
      * `vcenter` (`str`) - vSphere IP/hostname for vCenter (string)
      * `vcenterPort` (`str`) - vSphere Port for vCenter. Default `443` (string)
    """
    def __init__(__self__, resource_name, opts=None, amazonec2_credential_config=None, annotations=None, azure_credential_config=None, description=None, digitalocean_credential_config=None, labels=None, linode_credential_config=None, name=None, openstack_credential_config=None, vsphere_credential_config=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Rancher v2 Cloud Credential resource. This can be used to create Cloud Credential for Rancher v2.2.x and retrieve their information.

        amazonec2, azure, digitalocean, linode, openstack and vsphere credentials config are supported for Cloud Credential.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] amazonec2_credential_config: AWS config for the Cloud Credential (list maxitems:1)
        :param pulumi.Input[dict] annotations: Annotations for Cloud Credential object (map)
        :param pulumi.Input[dict] azure_credential_config: Azure config for the Cloud Credential (list maxitems:1)
        :param pulumi.Input[str] description: Description for the Cloud Credential (string)
        :param pulumi.Input[dict] digitalocean_credential_config: DigitalOcean config for the Cloud Credential (list maxitems:1)
        :param pulumi.Input[dict] labels: Labels for Cloud Credential object (map)
        :param pulumi.Input[dict] linode_credential_config: Linode config for the Cloud Credential (list maxitems:1)
        :param pulumi.Input[str] name: The name of the Cloud Credential (string)
        :param pulumi.Input[dict] openstack_credential_config: OpenStack config for the Cloud Credential (list maxitems:1)
        :param pulumi.Input[dict] vsphere_credential_config: vSphere config for the Cloud Credential (list maxitems:1)

        The **amazonec2_credential_config** object supports the following:

          * `access_key` (`pulumi.Input[str]`) - AWS access key (string)
          * `secret_key` (`pulumi.Input[str]`) - AWS secret key (string)

        The **azure_credential_config** object supports the following:

          * `client_id` (`pulumi.Input[str]`) - Azure Service Principal Account ID (string)
          * `client_secret` (`pulumi.Input[str]`) - Azure Service Principal Account password (string)
          * `subscriptionId` (`pulumi.Input[str]`) - Azure Subscription ID (string)

        The **digitalocean_credential_config** object supports the following:

          * `accessToken` (`pulumi.Input[str]`) - DigitalOcean access token (string)

        The **linode_credential_config** object supports the following:

          * `token` (`pulumi.Input[str]`) - Linode API token (string)

        The **openstack_credential_config** object supports the following:

          * `password` (`pulumi.Input[str]`) - vSphere password (string)

        The **vsphere_credential_config** object supports the following:

          * `password` (`pulumi.Input[str]`) - vSphere password (string)
          * `username` (`pulumi.Input[str]`) - vSphere username (string)
          * `vcenter` (`pulumi.Input[str]`) - vSphere IP/hostname for vCenter (string)
          * `vcenterPort` (`pulumi.Input[str]`) - vSphere Port for vCenter. Default `443` (string)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['amazonec2_credential_config'] = amazonec2_credential_config
            __props__['annotations'] = annotations
            __props__['azure_credential_config'] = azure_credential_config
            __props__['description'] = description
            __props__['digitalocean_credential_config'] = digitalocean_credential_config
            __props__['labels'] = labels
            __props__['linode_credential_config'] = linode_credential_config
            __props__['name'] = name
            __props__['openstack_credential_config'] = openstack_credential_config
            __props__['vsphere_credential_config'] = vsphere_credential_config
            __props__['driver'] = None
        super(CloudCredential, __self__).__init__(
            'rancher2:index/cloudCredential:CloudCredential',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, amazonec2_credential_config=None, annotations=None, azure_credential_config=None, description=None, digitalocean_credential_config=None, driver=None, labels=None, linode_credential_config=None, name=None, openstack_credential_config=None, vsphere_credential_config=None):
        """
        Get an existing CloudCredential resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] amazonec2_credential_config: AWS config for the Cloud Credential (list maxitems:1)
        :param pulumi.Input[dict] annotations: Annotations for Cloud Credential object (map)
        :param pulumi.Input[dict] azure_credential_config: Azure config for the Cloud Credential (list maxitems:1)
        :param pulumi.Input[str] description: Description for the Cloud Credential (string)
        :param pulumi.Input[dict] digitalocean_credential_config: DigitalOcean config for the Cloud Credential (list maxitems:1)
        :param pulumi.Input[str] driver: (Computed) The driver of the Cloud Credential (string)
        :param pulumi.Input[dict] labels: Labels for Cloud Credential object (map)
        :param pulumi.Input[dict] linode_credential_config: Linode config for the Cloud Credential (list maxitems:1)
        :param pulumi.Input[str] name: The name of the Cloud Credential (string)
        :param pulumi.Input[dict] openstack_credential_config: OpenStack config for the Cloud Credential (list maxitems:1)
        :param pulumi.Input[dict] vsphere_credential_config: vSphere config for the Cloud Credential (list maxitems:1)

        The **amazonec2_credential_config** object supports the following:

          * `access_key` (`pulumi.Input[str]`) - AWS access key (string)
          * `secret_key` (`pulumi.Input[str]`) - AWS secret key (string)

        The **azure_credential_config** object supports the following:

          * `client_id` (`pulumi.Input[str]`) - Azure Service Principal Account ID (string)
          * `client_secret` (`pulumi.Input[str]`) - Azure Service Principal Account password (string)
          * `subscriptionId` (`pulumi.Input[str]`) - Azure Subscription ID (string)

        The **digitalocean_credential_config** object supports the following:

          * `accessToken` (`pulumi.Input[str]`) - DigitalOcean access token (string)

        The **linode_credential_config** object supports the following:

          * `token` (`pulumi.Input[str]`) - Linode API token (string)

        The **openstack_credential_config** object supports the following:

          * `password` (`pulumi.Input[str]`) - vSphere password (string)

        The **vsphere_credential_config** object supports the following:

          * `password` (`pulumi.Input[str]`) - vSphere password (string)
          * `username` (`pulumi.Input[str]`) - vSphere username (string)
          * `vcenter` (`pulumi.Input[str]`) - vSphere IP/hostname for vCenter (string)
          * `vcenterPort` (`pulumi.Input[str]`) - vSphere Port for vCenter. Default `443` (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["amazonec2_credential_config"] = amazonec2_credential_config
        __props__["annotations"] = annotations
        __props__["azure_credential_config"] = azure_credential_config
        __props__["description"] = description
        __props__["digitalocean_credential_config"] = digitalocean_credential_config
        __props__["driver"] = driver
        __props__["labels"] = labels
        __props__["linode_credential_config"] = linode_credential_config
        __props__["name"] = name
        __props__["openstack_credential_config"] = openstack_credential_config
        __props__["vsphere_credential_config"] = vsphere_credential_config
        return CloudCredential(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetGlobalRoleBindingResult:
    """
    A collection of values returned by getGlobalRoleBinding.
    """
    def __init__(__self__, annotations=None, global_role_id=None, group_principal_id=None, id=None, labels=None, name=None, user_id=None):
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        __self__.annotations = annotations
        """
        (Computed) Annotations of the resource (map)
        """
        if global_role_id and not isinstance(global_role_id, str):
            raise TypeError("Expected argument 'global_role_id' to be a str")
        __self__.global_role_id = global_role_id
        if group_principal_id and not isinstance(group_principal_id, str):
            raise TypeError("Expected argument 'group_principal_id' to be a str")
        __self__.group_principal_id = group_principal_id
        """
        (Computed) The group principal ID to assign global role binding. Rancher v2.4.0 or higher is required (string)
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        """
        (Computed) Labels of the resource (map)
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        __self__.user_id = user_id
        """
        (Computed) The user ID to assign global role binding (string)
        """
class AwaitableGetGlobalRoleBindingResult(GetGlobalRoleBindingResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGlobalRoleBindingResult(
            annotations=self.annotations,
            global_role_id=self.global_role_id,
            group_principal_id=self.group_principal_id,
            id=self.id,
            labels=self.labels,
            name=self.name,
            user_id=self.user_id)

def get_global_role_binding(global_role_id=None,name=None,opts=None):
    """
    Use this data source to retrieve information about a Rancher v2 global role binding.




    :param str global_role_id: The global role id (string)
    :param str name: The name of the global role binding (string)
    """
    __args__ = dict()


    __args__['globalRoleId'] = global_role_id
    __args__['name'] = name
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('rancher2:index/getGlobalRoleBinding:getGlobalRoleBinding', __args__, opts=opts).value

    return AwaitableGetGlobalRoleBindingResult(
        annotations=__ret__.get('annotations'),
        global_role_id=__ret__.get('globalRoleId'),
        group_principal_id=__ret__.get('groupPrincipalId'),
        id=__ret__.get('id'),
        labels=__ret__.get('labels'),
        name=__ret__.get('name'),
        user_id=__ret__.get('userId'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class NodePool(pulumi.CustomResource):
    annotations: pulumi.Output[dict]
    """
    Annotations for Node Pool object (map)
    """
    cluster_id: pulumi.Output[str]
    """
    The RKE cluster id to use Node Pool (string)
    """
    control_plane: pulumi.Output[bool]
    """
    RKE control plane role for created nodes (bool)
    """
    delete_not_ready_after_secs: pulumi.Output[float]
    """
    Delete not ready node after secs. For Rancher v2.3.3 or above. Default `0` (int)
    """
    etcd: pulumi.Output[bool]
    """
    RKE etcd role for created nodes (bool)
    """
    hostname_prefix: pulumi.Output[str]
    """
    The prefix for created nodes of the Node Pool (string)
    """
    labels: pulumi.Output[dict]
    """
    Labels for Node Pool object (map)
    """
    name: pulumi.Output[str]
    """
    The name of the Node Pool (string)
    """
    node_taints: pulumi.Output[list]
    """
    Node taints. For Rancher v2.3.3 or above (List)

      * `effect` (`str`) - Taint effect. Supported values : `"NoExecute" | "NoSchedule" | "PreferNoSchedule"` (string)
      * `key` (`str`) - Taint key (string)
      * `timeAdded` (`str`) - Taint time added (string)
      * `value` (`str`) - Taint value (string)
    """
    node_template_id: pulumi.Output[str]
    """
    The Node Template ID to use for node creation (string)
    """
    quantity: pulumi.Output[float]
    """
    The number of nodes to create on Node Pool. Default `1`. Only values >= 1 allowed (int)
    """
    worker: pulumi.Output[bool]
    """
    RKE role role for created nodes (bool)
    """
    def __init__(__self__, resource_name, opts=None, annotations=None, cluster_id=None, control_plane=None, delete_not_ready_after_secs=None, etcd=None, hostname_prefix=None, labels=None, name=None, node_taints=None, node_template_id=None, quantity=None, worker=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Rancher v2 Node Pool resource. This can be used to create Node Pool, using Node template for Rancher v2 RKE clusters and retrieve their information.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for Node Pool object (map)
        :param pulumi.Input[str] cluster_id: The RKE cluster id to use Node Pool (string)
        :param pulumi.Input[bool] control_plane: RKE control plane role for created nodes (bool)
        :param pulumi.Input[float] delete_not_ready_after_secs: Delete not ready node after secs. For Rancher v2.3.3 or above. Default `0` (int)
        :param pulumi.Input[bool] etcd: RKE etcd role for created nodes (bool)
        :param pulumi.Input[str] hostname_prefix: The prefix for created nodes of the Node Pool (string)
        :param pulumi.Input[dict] labels: Labels for Node Pool object (map)
        :param pulumi.Input[str] name: The name of the Node Pool (string)
        :param pulumi.Input[list] node_taints: Node taints. For Rancher v2.3.3 or above (List)
        :param pulumi.Input[str] node_template_id: The Node Template ID to use for node creation (string)
        :param pulumi.Input[float] quantity: The number of nodes to create on Node Pool. Default `1`. Only values >= 1 allowed (int)
        :param pulumi.Input[bool] worker: RKE role role for created nodes (bool)

        The **node_taints** object supports the following:

          * `effect` (`pulumi.Input[str]`) - Taint effect. Supported values : `"NoExecute" | "NoSchedule" | "PreferNoSchedule"` (string)
          * `key` (`pulumi.Input[str]`) - Taint key (string)
          * `timeAdded` (`pulumi.Input[str]`) - Taint time added (string)
          * `value` (`pulumi.Input[str]`) - Taint value (string)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['annotations'] = annotations
            if cluster_id is None:
                raise TypeError("Missing required property 'cluster_id'")
            __props__['cluster_id'] = cluster_id
            __props__['control_plane'] = control_plane
            __props__['delete_not_ready_after_secs'] = delete_not_ready_after_secs
            __props__['etcd'] = etcd
            if hostname_prefix is None:
                raise TypeError("Missing required property 'hostname_prefix'")
            __props__['hostname_prefix'] = hostname_prefix
            __props__['labels'] = labels
            __props__['name'] = name
            __props__['node_taints'] = node_taints
            if node_template_id is None:
                raise TypeError("Missing required property 'node_template_id'")
            __props__['node_template_id'] = node_template_id
            __props__['quantity'] = quantity
            __props__['worker'] = worker
        super(NodePool, __self__).__init__(
            'rancher2:index/nodePool:NodePool',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, annotations=None, cluster_id=None, control_plane=None, delete_not_ready_after_secs=None, etcd=None, hostname_prefix=None, labels=None, name=None, node_taints=None, node_template_id=None, quantity=None, worker=None):
        """
        Get an existing NodePool resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for Node Pool object (map)
        :param pulumi.Input[str] cluster_id: The RKE cluster id to use Node Pool (string)
        :param pulumi.Input[bool] control_plane: RKE control plane role for created nodes (bool)
        :param pulumi.Input[float] delete_not_ready_after_secs: Delete not ready node after secs. For Rancher v2.3.3 or above. Default `0` (int)
        :param pulumi.Input[bool] etcd: RKE etcd role for created nodes (bool)
        :param pulumi.Input[str] hostname_prefix: The prefix for created nodes of the Node Pool (string)
        :param pulumi.Input[dict] labels: Labels for Node Pool object (map)
        :param pulumi.Input[str] name: The name of the Node Pool (string)
        :param pulumi.Input[list] node_taints: Node taints. For Rancher v2.3.3 or above (List)
        :param pulumi.Input[str] node_template_id: The Node Template ID to use for node creation (string)
        :param pulumi.Input[float] quantity: The number of nodes to create on Node Pool. Default `1`. Only values >= 1 allowed (int)
        :param pulumi.Input[bool] worker: RKE role role for created nodes (bool)

        The **node_taints** object supports the following:

          * `effect` (`pulumi.Input[str]`) - Taint effect. Supported values : `"NoExecute" | "NoSchedule" | "PreferNoSchedule"` (string)
          * `key` (`pulumi.Input[str]`) - Taint key (string)
          * `timeAdded` (`pulumi.Input[str]`) - Taint time added (string)
          * `value` (`pulumi.Input[str]`) - Taint value (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["annotations"] = annotations
        __props__["cluster_id"] = cluster_id
        __props__["control_plane"] = control_plane
        __props__["delete_not_ready_after_secs"] = delete_not_ready_after_secs
        __props__["etcd"] = etcd
        __props__["hostname_prefix"] = hostname_prefix
        __props__["labels"] = labels
        __props__["name"] = name
        __props__["node_taints"] = node_taints
        __props__["node_template_id"] = node_template_id
        __props__["quantity"] = quantity
        __props__["worker"] = worker
        return NodePool(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class Project(pulumi.CustomResource):
    annotations: pulumi.Output[dict]
    """
    Annotations for Node Pool object (map)
    """
    cluster_id: pulumi.Output[str]
    """
    The cluster id where create project (string)
    """
    container_resource_limit: pulumi.Output[dict]
    """
    Default containers resource limits on project (List maxitem:1)

      * `limitsCpu` (`str`) - Limit for limits cpu in project (string)
      * `limitsMemory` (`str`) - Limit for limits memory in project (string)
      * `requestsCpu` (`str`) - Limit for requests cpu in project (string)
      * `requestsMemory` (`str`) - Limit for requests memory in project (string)
    """
    description: pulumi.Output[str]
    """
    A project description (string)
    """
    enable_project_monitoring: pulumi.Output[bool]
    """
    Enable built-in project monitoring. Default `false` (bool)
    """
    labels: pulumi.Output[dict]
    """
    Labels for Node Pool object (map)
    """
    name: pulumi.Output[str]
    """
    The name of the project (string)
    """
    pod_security_policy_template_id: pulumi.Output[str]
    """
    Default Pod Security Policy ID for the project (string)
    """
    project_monitoring_input: pulumi.Output[dict]
    """
    Project monitoring config. Any parameter defined in [rancher-monitoring charts](https://github.com/rancher/system-charts/tree/dev/charts/rancher-monitoring) could be configured (list maxitems:1)

      * `answers` (`dict`) - Key/value answers for monitor input (map)
      * `version` (`str`) - rancher-monitoring chart version (string)
    """
    resource_quota: pulumi.Output[dict]
    """
    Resource quota for project. Rancher v2.1.x or higher (list maxitems:1)

      * `namespaceDefaultLimit` (`dict`) - Default resource quota limit for  namespaces in project (list maxitems:1)
        * `configMaps` (`str`) - Limit for config maps in project (string)
        * `limitsCpu` (`str`) - Limit for limits cpu in project (string)
        * `limitsMemory` (`str`) - Limit for limits memory in project (string)
        * `persistentVolumeClaims` (`str`) - Limit for persistent volume claims in project (string)
        * `pods` (`str`) - Limit for pods in project (string)
        * `replicationControllers` (`str`) - Limit for replication controllers in project (string)
        * `requestsCpu` (`str`) - Limit for requests cpu in project (string)
        * `requestsMemory` (`str`) - Limit for requests memory in project (string)
        * `requestsStorage` (`str`) - Limit for requests storage in project (string)
        * `secrets` (`str`) - Limit for secrets in project (string)
        * `services` (`str`)
        * `servicesLoadBalancers` (`str`) - Limit for services load balancers in project (string)
        * `servicesNodePorts` (`str`) - Limit for services node ports in project (string)

      * `projectLimit` (`dict`) - Resource quota limit for project (list maxitems:1)
        * `configMaps` (`str`) - Limit for config maps in project (string)
        * `limitsCpu` (`str`) - Limit for limits cpu in project (string)
        * `limitsMemory` (`str`) - Limit for limits memory in project (string)
        * `persistentVolumeClaims` (`str`) - Limit for persistent volume claims in project (string)
        * `pods` (`str`) - Limit for pods in project (string)
        * `replicationControllers` (`str`) - Limit for replication controllers in project (string)
        * `requestsCpu` (`str`) - Limit for requests cpu in project (string)
        * `requestsMemory` (`str`) - Limit for requests memory in project (string)
        * `requestsStorage` (`str`) - Limit for requests storage in project (string)
        * `secrets` (`str`) - Limit for secrets in project (string)
        * `services` (`str`)
        * `servicesLoadBalancers` (`str`) - Limit for services load balancers in project (string)
        * `servicesNodePorts` (`str`) - Limit for services node ports in project (string)
    """
    wait_for_cluster: pulumi.Output[bool]
    """
    Wait for cluster becomes active. Default `false` (bool)
    """
    def __init__(__self__, resource_name, opts=None, annotations=None, cluster_id=None, container_resource_limit=None, description=None, enable_project_monitoring=None, labels=None, name=None, pod_security_policy_template_id=None, project_monitoring_input=None, resource_quota=None, wait_for_cluster=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Rancher v2 Project resource. This can be used to create projects for Rancher v2 environments and retrieve their information.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for Node Pool object (map)
        :param pulumi.Input[str] cluster_id: The cluster id where create project (string)
        :param pulumi.Input[dict] container_resource_limit: Default containers resource limits on project (List maxitem:1)
        :param pulumi.Input[str] description: A project description (string)
        :param pulumi.Input[bool] enable_project_monitoring: Enable built-in project monitoring. Default `false` (bool)
        :param pulumi.Input[dict] labels: Labels for Node Pool object (map)
        :param pulumi.Input[str] name: The name of the project (string)
        :param pulumi.Input[str] pod_security_policy_template_id: Default Pod Security Policy ID for the project (string)
        :param pulumi.Input[dict] project_monitoring_input: Project monitoring config. Any parameter defined in [rancher-monitoring charts](https://github.com/rancher/system-charts/tree/dev/charts/rancher-monitoring) could be configured (list maxitems:1)
        :param pulumi.Input[dict] resource_quota: Resource quota for project. Rancher v2.1.x or higher (list maxitems:1)
        :param pulumi.Input[bool] wait_for_cluster: Wait for cluster becomes active. Default `false` (bool)

        The **container_resource_limit** object supports the following:

          * `limitsCpu` (`pulumi.Input[str]`) - Limit for limits cpu in project (string)
          * `limitsMemory` (`pulumi.Input[str]`) - Limit for limits memory in project (string)
          * `requestsCpu` (`pulumi.Input[str]`) - Limit for requests cpu in project (string)
          * `requestsMemory` (`pulumi.Input[str]`) - Limit for requests memory in project (string)

        The **project_monitoring_input** object supports the following:

          * `answers` (`pulumi.Input[dict]`) - Key/value answers for monitor input (map)
          * `version` (`pulumi.Input[str]`) - rancher-monitoring chart version (string)

        The **resource_quota** object supports the following:

          * `namespaceDefaultLimit` (`pulumi.Input[dict]`) - Default resource quota limit for  namespaces in project (list maxitems:1)
            * `configMaps` (`pulumi.Input[str]`) - Limit for config maps in project (string)
            * `limitsCpu` (`pulumi.Input[str]`) - Limit for limits cpu in project (string)
            * `limitsMemory` (`pulumi.Input[str]`) - Limit for limits memory in project (string)
            * `persistentVolumeClaims` (`pulumi.Input[str]`) - Limit for persistent volume claims in project (string)
            * `pods` (`pulumi.Input[str]`) - Limit for pods in project (string)
            * `replicationControllers` (`pulumi.Input[str]`) - Limit for replication controllers in project (string)
            * `requestsCpu` (`pulumi.Input[str]`) - Limit for requests cpu in project (string)
            * `requestsMemory` (`pulumi.Input[str]`) - Limit for requests memory in project (string)
            * `requestsStorage` (`pulumi.Input[str]`) - Limit for requests storage in project (string)
            * `secrets` (`pulumi.Input[str]`) - Limit for secrets in project (string)
            * `services` (`pulumi.Input[str]`)
            * `servicesLoadBalancers` (`pulumi.Input[str]`) - Limit for services load balancers in project (string)
            * `servicesNodePorts` (`pulumi.Input[str]`) - Limit for services node ports in project (string)

          * `projectLimit` (`pulumi.Input[dict]`) - Resource quota limit for project (list maxitems:1)
            * `configMaps` (`pulumi.Input[str]`) - Limit for config maps in project (string)
            * `limitsCpu` (`pulumi.Input[str]`) - Limit for limits cpu in project (string)
            * `limitsMemory` (`pulumi.Input[str]`) - Limit for limits memory in project (string)
            * `persistentVolumeClaims` (`pulumi.Input[str]`) - Limit for persistent volume claims in project (string)
            * `pods` (`pulumi.Input[str]`) - Limit for pods in project (string)
            * `replicationControllers` (`pulumi.Input[str]`) - Limit for replication controllers in project (string)
            * `requestsCpu` (`pulumi.Input[str]`) - Limit for requests cpu in project (string)
            * `requestsMemory` (`pulumi.Input[str]`) - Limit for requests memory in project (string)
            * `requestsStorage` (`pulumi.Input[str]`) - Limit for requests storage in project (string)
            * `secrets` (`pulumi.Input[str]`) - Limit for secrets in project (string)
            * `services` (`pulumi.Input[str]`)
            * `servicesLoadBalancers` (`pulumi.Input[str]`) - Limit for services load balancers in project (string)
            * `servicesNodePorts` (`pulumi.Input[str]`) - Limit for services node ports in project (string)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['annotations'] = annotations
            if cluster_id is None:
                raise TypeError("Missing required property 'cluster_id'")
            __props__['cluster_id'] = cluster_id
            __props__['container_resource_limit'] = container_resource_limit
            __props__['description'] = description
            __props__['enable_project_monitoring'] = enable_project_monitoring
            __props__['labels'] = labels
            __props__['name'] = name
            __props__['pod_security_policy_template_id'] = pod_security_policy_template_id
            __props__['project_monitoring_input'] = project_monitoring_input
            __props__['resource_quota'] = resource_quota
            __props__['wait_for_cluster'] = wait_for_cluster
        super(Project, __self__).__init__(
            'rancher2:index/project:Project',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, annotations=None, cluster_id=None, container_resource_limit=None, description=None, enable_project_monitoring=None, labels=None, name=None, pod_security_policy_template_id=None, project_monitoring_input=None, resource_quota=None, wait_for_cluster=None):
        """
        Get an existing Project resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for Node Pool object (map)
        :param pulumi.Input[str] cluster_id: The cluster id where create project (string)
        :param pulumi.Input[dict] container_resource_limit: Default containers resource limits on project (List maxitem:1)
        :param pulumi.Input[str] description: A project description (string)
        :param pulumi.Input[bool] enable_project_monitoring: Enable built-in project monitoring. Default `false` (bool)
        :param pulumi.Input[dict] labels: Labels for Node Pool object (map)
        :param pulumi.Input[str] name: The name of the project (string)
        :param pulumi.Input[str] pod_security_policy_template_id: Default Pod Security Policy ID for the project (string)
        :param pulumi.Input[dict] project_monitoring_input: Project monitoring config. Any parameter defined in [rancher-monitoring charts](https://github.com/rancher/system-charts/tree/dev/charts/rancher-monitoring) could be configured (list maxitems:1)
        :param pulumi.Input[dict] resource_quota: Resource quota for project. Rancher v2.1.x or higher (list maxitems:1)
        :param pulumi.Input[bool] wait_for_cluster: Wait for cluster becomes active. Default `false` (bool)

        The **container_resource_limit** object supports the following:

          * `limitsCpu` (`pulumi.Input[str]`) - Limit for limits cpu in project (string)
          * `limitsMemory` (`pulumi.Input[str]`) - Limit for limits memory in project (string)
          * `requestsCpu` (`pulumi.Input[str]`) - Limit for requests cpu in project (string)
          * `requestsMemory` (`pulumi.Input[str]`) - Limit for requests memory in project (string)

        The **project_monitoring_input** object supports the following:

          * `answers` (`pulumi.Input[dict]`) - Key/value answers for monitor input (map)
          * `version` (`pulumi.Input[str]`) - rancher-monitoring chart version (string)

        The **resource_quota** object supports the following:

          * `namespaceDefaultLimit` (`pulumi.Input[dict]`) - Default resource quota limit for  namespaces in project (list maxitems:1)
            * `configMaps` (`pulumi.Input[str]`) - Limit for config maps in project (string)
            * `limitsCpu` (`pulumi.Input[str]`) - Limit for limits cpu in project (string)
            * `limitsMemory` (`pulumi.Input[str]`) - Limit for limits memory in project (string)
            * `persistentVolumeClaims` (`pulumi.Input[str]`) - Limit for persistent volume claims in project (string)
            * `pods` (`pulumi.Input[str]`) - Limit for pods in project (string)
            * `replicationControllers` (`pulumi.Input[str]`) - Limit for replication controllers in project (string)
            * `requestsCpu` (`pulumi.Input[str]`) - Limit for requests cpu in project (string)
            * `requestsMemory` (`pulumi.Input[str]`) - Limit for requests memory in project (string)
            * `requestsStorage` (`pulumi.Input[str]`) - Limit for requests storage in project (string)
            * `secrets` (`pulumi.Input[str]`) - Limit for secrets in project (string)
            * `services` (`pulumi.Input[str]`)
            * `servicesLoadBalancers` (`pulumi.Input[str]`) - Limit for services load balancers in project (string)
            * `servicesNodePorts` (`pulumi.Input[str]`) - Limit for services node ports in project (string)

          * `projectLimit` (`pulumi.Input[dict]`) - Resource quota limit for project (list maxitems:1)
            * `configMaps` (`pulumi.Input[str]`) - Limit for config maps in project (string)
            * `limitsCpu` (`pulumi.Input[str]`) - Limit for limits cpu in project (string)
            * `limitsMemory` (`pulumi.Input[str]`) - Limit for limits memory in project (string)
            * `persistentVolumeClaims` (`pulumi.Input[str]`) - Limit for persistent volume claims in project (string)
            * `pods` (`pulumi.Input[str]`) - Limit for pods in project (string)
            * `replicationControllers` (`pulumi.Input[str]`) - Limit for replication controllers in project (string)
            * `requestsCpu` (`pulumi.Input[str]`) - Limit for requests cpu in project (string)
            * `requestsMemory` (`pulumi.Input[str]`) - Limit for requests memory in project (string)
            * `requestsStorage` (`pulumi.Input[str]`) - Limit for requests storage in project (string)
            * `secrets` (`pulumi.Input[str]`) - Limit for secrets in project (string)
            * `services` (`pulumi.Input[str]`)
            * `servicesLoadBalancers` (`pulumi.Input[str]`) - Limit for services load balancers in project (string)
            * `servicesNodePorts` (`pulumi.Input[str]`) - Limit for services node ports in project (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["annotations"] = annotations
        __props__["cluster_id"] = cluster_id
        __props__["container_resource_limit"] = container_resource_limit
        __props__["description"] = description
        __props__["enable_project_monitoring"] = enable_project_monitoring
        __props__["labels"] = labels
        __props__["name"] = name
        __props__["pod_security_policy_template_id"] = pod_security_policy_template_id
        __props__["project_monitoring_input"] = project_monitoring_input
        __props__["resource_quota"] = resource_quota
        __props__["wait_for_cluster"] = wait_for_cluster
        return Project(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

